@@ -1,36 +1,36 @@
 /*
  * Copyright (c) 2000-2001 Silicon Graphics, Inc.  All Rights Reserved.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
+ *
  * This program is distributed in the hope that it would be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
+ *
  * Further, this software is distributed without any warranty that it is
  * free of the rightful claim of any third person regarding infringement
  * or the like.  Any license provided herein, whether implied or
  * otherwise, applies only to this software file.  Patent licenses, if
  * any, provided herein do not apply to combinations of this program with
  * other software, or any other product whatsoever.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write the Free Software Foundation, Inc., 59
  * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
+ *
  * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
  * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
+ *
+ * http://www.sgi.com
+ *
+ * For further information regarding this notice, see:
+ *
  * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
  */
 
-#include <libxfs.h>
+#include <xfs/libxfs.h>
 #include "bit.h"
 #include "type.h"
 #include "faddr.h"
@@ -38,8 +38,7 @@
 #include "field.h"
 #include "attr.h"
 #include "io.h"
-#include "data.h"
-#include "mount.h"
+#include "init.h"
 
 static int	attr_leaf_entries_count(void *obj, int startoff);
 static int	attr_leaf_hdr_count(void *obj, int startoff);
@@ -167,7 +166,7 @@ attr_leaf_entries_count(
 	int			startoff)
 {
 	xfs_attr_leafblock_t	*block;
-	
+
 	ASSERT(startoff == 0);
 	block = obj;
 	if (INT_GET(block->hdr.info.magic, ARCH_CONVERT)
@@ -185,7 +184,7 @@ attr_leaf_hdr_count(
 	int			startoff)
 {
 	xfs_attr_leafblock_t	*block;
-	
+
 	ASSERT(startoff == 0);
 	block = obj;
 	return INT_GET(block->hdr.info.magic, ARCH_CONVERT)
@@ -297,14 +296,14 @@ attr_leaf_name_local_value_offset(
 	if (INT_GET(block->hdr.info.magic, ARCH_CONVERT)
 						!= XFS_ATTR_LEAF_MAGIC)
 		return 0;
-        
+
 	for (i = 0; i < INT_GET(block->hdr.count, ARCH_CONVERT); i++) {
 		e = &block->entries[i];
 		if (INT_GET(e->nameidx, ARCH_CONVERT) == off)
-                    break;
+		    break;
 	}
-        if (i>=INT_GET(block->hdr.count, ARCH_CONVERT)) return 0;
-        
+	if (i>=INT_GET(block->hdr.count, ARCH_CONVERT)) return 0;
+
 	l = XFS_ATTR_LEAF_NAME_LOCAL(block, i);
 	vp = (char *)&l->nameval[l->namelen];
 	return (int)bitize(vp - (char *)l);
@@ -447,7 +446,7 @@ attr_node_hdr_count(
 	int			startoff)
 {
 	xfs_da_intnode_t	*block;
-	
+
 	ASSERT(startoff == 0);
 	block = obj;
 	return INT_GET(block->hdr.info.magic, ARCH_CONVERT)
