@@ -1,36 +1,36 @@
 /*
  * Copyright (c) 2000-2001 Silicon Graphics, Inc.  All Rights Reserved.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
+ *
  * This program is distributed in the hope that it would be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
+ *
  * Further, this software is distributed without any warranty that it is
  * free of the rightful claim of any third person regarding infringement
  * or the like.  Any license provided herein, whether implied or
  * otherwise, applies only to this software file.  Patent licenses, if
  * any, provided herein do not apply to combinations of this program with
  * other software, or any other product whatsoever.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write the Free Software Foundation, Inc., 59
  * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
+ *
  * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
  * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
+ *
+ * http://www.sgi.com
+ *
+ * For further information regarding this notice, see:
+ *
  * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
  */
 
-#include <libxfs.h>
+#include <xfs/libxfs.h>
 #include "type.h"
 #include "faddr.h"
 #include "fprint.h"
@@ -80,7 +80,7 @@ attr_sf_entry_name_count(
 	int			startoff)
 {
 	xfs_attr_sf_entry_t	*e;
-	
+
 	ASSERT(bitoffs(startoff) == 0);
 	e = (xfs_attr_sf_entry_t *)((char *)obj + byteize(startoff));
 	return e->namelen;
@@ -110,7 +110,7 @@ attr_sf_entry_value_count(
 	int			startoff)
 {
 	xfs_attr_sf_entry_t	*e;
-	
+
 	ASSERT(bitoffs(startoff) == 0);
 	e = (xfs_attr_sf_entry_t *)((char *)obj + byteize(startoff));
 	return e->valuelen;
@@ -124,7 +124,7 @@ attr_sf_entry_value_offset(
 	int			idx)
 {
 	xfs_attr_sf_entry_t	*e;
-	
+
 	ASSERT(bitoffs(startoff) == 0);
 	ASSERT(idx == 0);
 	e = (xfs_attr_sf_entry_t *)((char *)obj + byteize(startoff));
