@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000-2002 Silicon Graphics, Inc.  All Rights Reserved.
+ * Copyright (c) 2000-2003 Silicon Graphics, Inc.  All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
@@ -32,46 +32,45 @@
 #ifndef __LIBXFS_H__
 #define __LIBXFS_H__
 
-#include "platform_defs.h"
+#include <xfs/platform_defs.h>
 
-#include <xfs_fs.h>
-#include <xfs_types.h>
-#include <xfs_arch.h>
-#include <xfs_sb.h>
-#include <xfs_bit.h>
-#include <xfs_inum.h>
-#include <xfs_ag.h>
-#include <xfs_da_btree.h>
-#include <xfs_bmap_btree.h>
-#include <xfs_alloc_btree.h>
-#include <xfs_ialloc_btree.h>
-#include <xfs_alloc.h>
-#include <xfs_ialloc.h>
-#include <xfs_rtalloc.h>
-#include <xfs_btree.h>
-#include <xfs_dir.h>
-#include <xfs_dir_sf.h>
-#include <xfs_dir_leaf.h>
-#include <xfs_dir2.h>
-#include <xfs_dir2_data.h>
-#include <xfs_dir2_leaf.h>
-#include <xfs_dir2_block.h>
-#include <xfs_dir2_node.h>
-#include <xfs_dir2_sf.h>
-#include <xfs_attr_sf.h>
-#include <xfs_dinode.h>
-#include <xfs_attr_leaf.h>
-#include <xfs_quota.h>
-#include <xfs_dqblk.h>
-#include <xfs_mount.h>
-#include <xfs_trans_space.h>
-#include <xfs_inode.h>
-#include <xfs_buf_item.h>
-#include <xfs_inode_item.h>
-#include <xfs_bmap.h>
-#include <xfs_imap.h>
-#include <xfs_log.h>
-#include <xfs_log_priv.h>
+#include <xfs/xfs_fs.h>
+#include <xfs/xfs_types.h>
+#include <xfs/xfs_arch.h>
+#include <xfs/xfs_sb.h>
+#include <xfs/xfs_bit.h>
+#include <xfs/xfs_inum.h>
+#include <xfs/xfs_ag.h>
+#include <xfs/xfs_da_btree.h>
+#include <xfs/xfs_bmap_btree.h>
+#include <xfs/xfs_alloc_btree.h>
+#include <xfs/xfs_ialloc_btree.h>
+#include <xfs/xfs_alloc.h>
+#include <xfs/xfs_ialloc.h>
+#include <xfs/xfs_rtalloc.h>
+#include <xfs/xfs_btree.h>
+#include <xfs/xfs_dir.h>
+#include <xfs/xfs_dir_sf.h>
+#include <xfs/xfs_dir_leaf.h>
+#include <xfs/xfs_dir2.h>
+#include <xfs/xfs_dir2_data.h>
+#include <xfs/xfs_dir2_leaf.h>
+#include <xfs/xfs_dir2_block.h>
+#include <xfs/xfs_dir2_node.h>
+#include <xfs/xfs_dir2_sf.h>
+#include <xfs/xfs_attr_sf.h>
+#include <xfs/xfs_dinode.h>
+#include <xfs/xfs_attr_leaf.h>
+#include <xfs/xfs_quota.h>
+#include <xfs/xfs_mount.h>
+#include <xfs/xfs_trans_space.h>
+#include <xfs/xfs_inode.h>
+#include <xfs/xfs_buf_item.h>
+#include <xfs/xfs_inode_item.h>
+#include <xfs/xfs_bmap.h>
+#include <xfs/xfs_imap.h>
+#include <xfs/xfs_log.h>
+#include <xfs/xfs_log_priv.h>
 
 #ifndef XFS_SUPER_MAGIC
 #define XFS_SUPER_MAGIC 0x58465342
@@ -81,35 +80,41 @@
  * Argument structure for libxfs_init().
  */
 typedef struct {
-                                /* input parameters */
-        char            *volname;       /* pathname of volume */
-        char            *dname;         /* pathname of data "subvolume" */
-        char            *logname;       /* pathname of log "subvolume" */
-        char            *rtname;        /* pathname of realtime "subvolume" */
-        int             isreadonly;     /* filesystem is only read in applic */
-        int             disfile;        /* data "subvolume" is a regular file */        int             dcreat;         /* try to create data subvolume */
-        int             lisfile;        /* log "subvolume" is a regular file */
-        int             lcreat;         /* try to create log subvolume */
-        int             risfile;        /* realtime "subvolume" is a reg file */        int             rcreat;         /* try to create realtime subvolume */
-        char            *notvolmsg;     /* format string for not XLV message */
-        int             notvolok;       /* set if not XLV => try data */
-                                /* output results */
-        dev_t           ddev;           /* device for data subvolume */
-        dev_t           logdev;         /* device for log subvolume */
-        dev_t           rtdev;          /* device for realtime subvolume */
-        long long       dsize;          /* size of data subvolume (BBs) */
-        long long       logBBsize;      /* size of log subvolume (BBs) */
-                                        /* (blocks allocated for use as 
-                                         * log is stored in mount structure) */
-        long long       logBBstart;     /* start block of log subvolume (BBs) */        long long       rtsize;         /* size of realtime subvolume (BBs) */
-        int             dfd;            /* data subvolume file descriptor */
-        int             logfd;          /* log subvolume file descriptor */
-        int             rtfd;           /* realtime subvolume file descriptor */
-	int		setblksize; 	/* attempt to set device block size */
+				/* input parameters */
+	char            *volname;       /* pathname of volume */
+	char            *dname;         /* pathname of data "subvolume" */
+	char            *logname;       /* pathname of log "subvolume" */
+	char            *rtname;        /* pathname of realtime "subvolume" */
+	int             isreadonly;     /* filesystem is only read in applic */
+	int             disfile;        /* data "subvolume" is a regular file */        int             dcreat;         /* try to create data subvolume */
+	int             lisfile;        /* log "subvolume" is a regular file */
+	int             lcreat;         /* try to create log subvolume */
+	int             risfile;        /* realtime "subvolume" is a reg file */        int             rcreat;         /* try to create realtime subvolume */
+	char            *notvolmsg;     /* format string for not XLV message */
+	int             notvolok;       /* set if not XLV => try data */
+	int		setblksize;	/* attempt to set device blksize */
+				/* output results */
+	dev_t           ddev;           /* device for data subvolume */
+	dev_t           logdev;         /* device for log subvolume */
+	dev_t           rtdev;          /* device for realtime subvolume */
+	long long       dsize;          /* size of data subvolume (BBs) */
+	long long       logBBsize;      /* size of log subvolume (BBs) */
+					/* (blocks allocated for use as
+					 * log is stored in mount structure) */
+	long long       logBBstart;     /* start block of log subvolume (BBs) */
+	long long       rtsize;         /* size of realtime subvolume (BBs) */
+	int		dbsize;		/* data subvolume device blksize */
+	int		lbsize;		/* log subvolume device blksize */
+	int		rtbsize;	/* realtime subvolume device blksize */
+	int             dfd;            /* data subvolume file descriptor */
+	int             logfd;          /* log subvolume file descriptor */
+	int             rtfd;           /* realtime subvolume file descriptor */
 } libxfs_init_t;
 
-#define LIBXFS_ISREADONLY	0x0069	/* disallow all mounted filesystems */
-#define LIBXFS_ISINACTIVE	0x6900	/* allow mounted only if mounted ro */
+#define LIBXFS_EXIT_ON_FAILURE	0x0001	/* exit the program if a call fails */
+#define LIBXFS_ISREADONLY	0x0002	/* disallow all mounted filesystems */
+#define LIBXFS_ISINACTIVE	0x0004	/* allow mounted only if mounted ro */
+#define LIBXFS_DANGEROUSLY	0x0008	/* repair is mounted ro */
 
 extern char	*progname;
 extern int	libxfs_init (libxfs_init_t *);
@@ -119,10 +124,15 @@ extern void	libxfs_device_zero (dev_t, xfs_daddr_t, uint);
 extern void	libxfs_device_close (dev_t);
 
 /* check or write log footer: specify device, log size in blocks & uuid */
+typedef xfs_caddr_t (libxfs_get_block_t)(xfs_caddr_t, int, void *);
+
 extern int	libxfs_log_clear (dev_t, xfs_daddr_t, uint, uuid_t *,
 				int, int, int);
+extern int	libxfs_log_header (xfs_caddr_t, uuid_t *, int, int, int,
+				libxfs_get_block_t *, void *);
 
-/* 
+
+/*
  * Define a user-level mount structure with all we need
  * in order to make use of the numerous XFS_* macros.
  */
@@ -144,6 +154,7 @@ typedef struct xfs_mount {
 	__uint8_t		m_dircook_elog;	/* log d-cookie entry bits */
 	__uint8_t		m_blkbit_log;	/* blocklog + NBBY */
 	__uint8_t		m_blkbb_log;	/* blocklog - BBSHIFT */
+	__uint8_t		m_sectbb_log;	/* sectorlog - BBSHIFT */
 	__uint8_t		m_agno_log;	/* log #ag's */
 	__uint8_t		m_agino_log;	/* #bits for agino in inum */
 	__uint16_t		m_inode_cluster_size;/* min inode buf size */
@@ -163,7 +174,8 @@ typedef struct xfs_mount {
 	uint			m_flags;	/* global mount flags */
 	uint			m_qflags;	/* quota status flags */
 	uint			m_attroffset;	/* inode attribute offset */
-	int			m_da_node_ents;	/* how many entries in danode */
+	uint			m_dir_node_ents; /* #entries in a dir danode */
+	uint			m_attr_node_ents; /* #entries in attr danode */
 	int			m_ialloc_inos;	/* inodes in inode allocation */
 	int			m_ialloc_blks;	/* blocks in inode allocation */
 	int			m_litino;	/* size of inode union area */
@@ -172,7 +184,6 @@ typedef struct xfs_mount {
 	__uint64_t		m_maxicount;	/* maximum inode count */
 	int			m_dalign;	/* stripe unit */
 	int			m_swidth;	/* stripe width */
-	int			m_lstripemask;	/* log stripe mask */
 	int			m_sinoalign;	/* stripe unit inode alignmnt */
 	int			m_dir_magicpct;	/* 37% of the dir blocksize */
 	__uint8_t		m_dirversion;	/* 1 or 2 */
@@ -183,6 +194,8 @@ typedef struct xfs_mount {
 	xfs_dablk_t		m_dirfreeblk;	/* blockno of dirfreeindex v2 */
 } xfs_mount_t;
 
+#define LIBXFS_MOUNT_ROOTINOS	0x0001
+#define LIBXFS_MOUNT_DEBUGGER	0x0002
 
 extern xfs_mount_t	*libxfs_mount (xfs_mount_t *, xfs_sb_t *,
 				dev_t, dev_t, dev_t, int);
@@ -261,7 +274,7 @@ typedef struct xfs_buf_log_item {
 	xfs_buf_log_format_t	bli_format;	/* in-log header */
 } xfs_buf_log_item_t;
 
-#include <xfs_trans.h>
+#include <xfs/xfs_trans.h>
 
 typedef struct xfs_trans {
 	unsigned int	t_type;			/* transaction type */
@@ -434,9 +447,12 @@ extern int	libxfs_alloc_file_space (xfs_inode_t *, xfs_off_t,
 extern xfs_dahash_t	libxfs_da_hashname (uchar_t *, int);
 extern int	libxfs_attr_leaf_newentsize (xfs_da_args_t *, int, int *);
 
-extern xfs_filblks_t	libxfs_bmbt_get_blockcount (xfs_bmbt_rec_t *);
-extern xfs_fileoff_t	libxfs_bmbt_get_startoff (xfs_bmbt_rec_t *);
 extern void	libxfs_bmbt_get_all (xfs_bmbt_rec_t *, xfs_bmbt_irec_t *);
+#if ARCH_CONVERT != ARCH_NOCONVERT
+extern void	libxfs_bmbt_disk_get_all (xfs_bmbt_rec_t *, xfs_bmbt_irec_t *);
+#else
+# define libxfs_bmbt_disk_get_all(r,s)	libxfs_bmbt_get_all(r,s)
+#endif
 
 extern int	libxfs_free_extent (xfs_trans_t *, xfs_fsblock_t, xfs_extlen_t);
 extern int	libxfs_rtfree_extent (xfs_trans_t *, xfs_rtblock_t,
