@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000-2001 Silicon Graphics, Inc.  All Rights Reserved.
+ * Copyright (c) 2000-2003 Silicon Graphics, Inc.  All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
@@ -32,7 +32,7 @@
 #ifndef LIBXLOG_H
 #define LIBXLOG_H
 
-#include <libxfs.h>
+#include <xfs/libxfs.h>
 
 /*
  * define the userlevel xlog_t to be the subset of the kernel's
@@ -58,22 +58,32 @@ typedef struct log {
 	int		l_grant_reserve_bytes;	/* */
 	int		l_grant_write_cycle;	/* */
 	int		l_grant_write_bytes;	/* */
+	uint		l_sectbb_log;   /* log2 of sector size in bbs */
 } xlog_t;
 
-#include <xfs_log_recover.h>
-#include <xfs_buf_item.h>
-#include <xfs_inode_item.h>
-#include <xfs_extfree_item.h>
-#include <xfs_dquot_item.h>
+#include <xfs/xfs_log_recover.h>
+#include <xfs/xfs_buf_item.h>
+#include <xfs/xfs_inode_item.h>
+#include <xfs/xfs_extfree_item.h>
 
+typedef union {
+	xlog_rec_header_t       hic_header;
+	xlog_rec_ext_header_t   hic_xheader;
+	char                    hic_sector[XLOG_HEADER_SIZE];
+} xlog_in_core_2_t;
 
 /*
  * macros mapping kernel code to user code
  */
-#define STATIC			static
-#define EFSCORRUPTED            990
-#define XFS_ERROR(e)		(e)
-#define min(a,b)		((a) < (b) ? (a) : (b))
+#ifndef EFSCORRUPTED
+#define EFSCORRUPTED			 990
+#endif
+#define STATIC				static
+#define XFS_ERROR(e)			(e)
+#define XFS_ERROR_REPORT(e,l,mp)	((void) 0)
+#define XFS_CORRUPTION_ERROR(e,l,mp,m)	((void) 0)
+#define unlikely(x)			(x)
+#define min(a,b)			((a) < (b) ? (a) : (b))
 
 #if (__GNUC__ < 2) || ((__GNUC__ == 2) && (__GNUC_MINOR__ <= 95))
 # define xlog_warn(fmt,args...) \
@@ -95,13 +105,15 @@ typedef struct log {
 	xlog_exit(__VA_ARGS__)
 #endif
 
-#define xlog_get_bp(nbblks, mp)	libxfs_getbuf(x.logdev, 0, (nbblks))
+#define xlog_get_bp(log,bbs)	libxfs_getbuf(x.logdev, 0, (bbs))
 #define xlog_put_bp(bp)		libxfs_putbuf(bp)
-#define xlog_bread(log,blkno,nbblks,bp)	\
+#define xlog_bread(log,blkno,bbs,bp)	\
 	(libxfs_readbufr(x.logdev,	\
-			(log)->l_logBBstart+(blkno), bp, (nbblks), 1), 0)
-                         
+			(log)->l_logBBstart+(blkno), bp, (bbs), 1), 0)
+#define xlog_align(log,blkno,nbblks,bp)	XFS_BUF_PTR(bp)
+
 #define kmem_zalloc(size, foo)			calloc(size,1)
+#define kmem_alloc(size, foo)			calloc(size,1)
 #define kmem_free(ptr, foo)			free(ptr)
 #define kmem_realloc(ptr, len, old, foo)	realloc(ptr, len)
 
@@ -116,7 +128,7 @@ extern void xfs_log_print_trans(xlog_t          *log,
 				int		print_block_start);
 
 extern void xfs_log_print(      xlog_t          *log,
-                                int             fd,
+				int             fd,
 				int		print_block_start);
 
 extern int  xlog_find_zeroed(xlog_t *log, xfs_daddr_t *blk_no);
@@ -150,9 +162,9 @@ extern int  xlog_do_recovery_pass(	xlog_t		*log,
 extern int  xlog_recover_do_trans(	xlog_t		*log,
 					xlog_recover_t	*trans,
 					int		pass);
-extern int  xlog_header_check_recover(  xfs_mount_t         *mp, 
-                                        xlog_rec_header_t   *head);
-extern int  xlog_header_check_mount(    xfs_mount_t         *mp, 
-                                        xlog_rec_header_t   *head);
+extern int  xlog_header_check_recover(  xfs_mount_t         *mp,
+					xlog_rec_header_t   *head);
+extern int  xlog_header_check_mount(    xfs_mount_t         *mp,
+					xlog_rec_header_t   *head);
 
 #endif	/* LIBXLOG_H */
