@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000-2002 Silicon Graphics, Inc.  All Rights Reserved.
+ * Copyright (c) 2000-2003 Silicon Graphics, Inc.  All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
@@ -40,7 +40,7 @@
  *
  * It should only ever be #include'd by XFS "kernel" code being
  * compiled in user space.
- * 
+ *
  * Our goals here are to...
  *      o  "share" large amounts of complex code between user and
  *         kernel space;
@@ -56,10 +56,7 @@
  *         specifically there to support the user level build.
  */
 
-#include <libxfs.h>
-#include <string.h>
-#include <errno.h>
-#include <sys/stat.h>
+#include <xfs/libxfs.h>
 
 /*
  * Map XFS kernel routine names to libxfs.h names
@@ -67,22 +64,26 @@
 
 #define xfs_xlatesb			libxfs_xlate_sb
 #define xfs_xlate_dinode_core		libxfs_xlate_dinode_core
-#define xfs_bmbt_get_all                libxfs_bmbt_get_all
-#define xfs_bmbt_get_blockcount         libxfs_bmbt_get_blockcount
-#define xfs_bmbt_get_startoff           libxfs_bmbt_get_startoff
-#define xfs_da_hashname                 libxfs_da_hashname
-#define xfs_da_log2_roundup             libxfs_da_log2_roundup
-#define xfs_highbit32                   libxfs_highbit32
-#define xfs_highbit64                   libxfs_highbit64
-#define xfs_attr_leaf_newentsize        libxfs_attr_leaf_newentsize
-#define xfs_alloc_compute_maxlevels     libxfs_alloc_compute_maxlevels
-#define xfs_bmap_compute_maxlevels      libxfs_bmap_compute_maxlevels
-#define xfs_ialloc_compute_maxlevels    libxfs_ialloc_compute_maxlevels
+#if ARCH_CONVERT != ARCH_NOCONVERT
+#define xfs_bmbt_get_all		libxfs_bmbt_get_all
+#define xfs_bmbt_disk_get_all		libxfs_bmbt_disk_get_all
+#else
+#define xfs_bmbt_get_all		libxfs_bmbt_get_all
+#define xfs_bmbt_disk_get_all		libxfs_bmbt_get_all
+#endif
+#define xfs_da_hashname			libxfs_da_hashname
+#define xfs_da_log2_roundup		libxfs_da_log2_roundup
+#define xfs_highbit32			libxfs_highbit32
+#define xfs_highbit64			libxfs_highbit64
+#define xfs_attr_leaf_newentsize	libxfs_attr_leaf_newentsize
+#define xfs_alloc_compute_maxlevels	libxfs_alloc_compute_maxlevels
+#define xfs_bmap_compute_maxlevels	libxfs_bmap_compute_maxlevels
+#define xfs_ialloc_compute_maxlevels	libxfs_ialloc_compute_maxlevels
 
 #define xfs_dir_init			libxfs_dir_init
 #define xfs_dir2_init			libxfs_dir2_init
-#define xfs_dir_mount                   libxfs_dir_mount
-#define xfs_dir2_mount                  libxfs_dir2_mount
+#define xfs_dir_mount			libxfs_dir_mount
+#define xfs_dir2_mount			libxfs_dir2_mount
 #define xfs_dir_createname		libxfs_dir_createname
 #define xfs_dir2_createname		libxfs_dir2_createname
 #define xfs_dir_lookup			libxfs_dir_lookup
@@ -94,9 +95,9 @@
 #define xfs_dir_bogus_removename	libxfs_dir_bogus_removename
 #define xfs_dir2_bogus_removename	libxfs_dir2_bogus_removename
 
-#define xfs_mount_common                libxfs_mount_common
-#define xfs_initialize_perag            libxfs_initialize_perag
-#define xfs_rtmount_init                libxfs_rtmount_init
+#define xfs_mount_common		libxfs_mount_common
+#define xfs_initialize_perag		libxfs_initialize_perag
+#define xfs_rtmount_init		libxfs_rtmount_init
 #define xfs_alloc_fix_freelist		libxfs_alloc_fix_freelist
 #define xfs_iread			libxfs_iread
 #define xfs_ialloc			libxfs_ialloc
@@ -112,7 +113,7 @@
 #define xfs_mod_sb			libxfs_mod_sb
 #define xfs_mod_incore_sb		libxfs_mod_incore_sb
 
-#define xfs_trans_init                  libxfs_trans_init
+#define xfs_trans_init			libxfs_trans_init
 #define xfs_trans_dup			libxfs_trans_dup
 #define xfs_trans_iget			libxfs_trans_iget
 #define xfs_trans_ijoin			libxfs_trans_ijoin
@@ -134,7 +135,7 @@
 #define xfs_da_shrink_inode		libxfs_da_shrink_inode
 #define xfs_da_grow_inode		libxfs_da_grow_inode
 #define xfs_da_brelse			libxfs_da_brelse
-#define xfs_da_read_buf			libxfs_da_read_buf		
+#define xfs_da_read_buf			libxfs_da_read_buf
 #define xfs_da_get_buf			libxfs_da_get_buf
 #define xfs_da_log_buf			libxfs_da_log_buf
 #define xfs_da_do_buf			libxfs_da_do_buf
@@ -168,7 +169,7 @@
 #define xfs_baread(a,b,c)		((void) 0)	/* no readahead */
 #define xfs_buftrace(x,y)		((void) 0)	/* debug only */
 #define xfs_buf_item_log_debug(bip,a,b)	((void) 0)	/* debug only */
-#define xfs_validate_extents(e,n,f)	((void) 0)	/* debug only */
+#define xfs_validate_extents(e,n,d,f)	((void) 0)	/* debug only */
 #define xfs_buf_relse(bp)		libxfs_putbuf(bp)
 #define xfs_read_buf(mp,devp,blkno,len,f,bpp)	\
 	( *(bpp) = libxfs_readbuf( *(dev_t*)devp, (blkno), (len), 1), 0 )
@@ -187,7 +188,7 @@
 /* memory management */
 #define KM_SLEEP	1
 #define KM_SLEEP_IO	2
-#define kmem_zone		xfs_zone	
+#define kmem_zone		xfs_zone
 #define kmem_zone_t		xfs_zone_t
 #define kmem_zone_init(a, b)	libxfs_zone_init(a, b)
 #define kmem_zone_alloc(z, f)	libxfs_zone_zalloc(z)
@@ -232,24 +233,33 @@
 #define xfs_alloc_mark_busy(tp,ag,b,len)		((void) 0)
 
 /* anything else */
+#if !defined(__sgi__)
 typedef __uint32_t uint_t;
 typedef __uint32_t inst_t;	/* an instruction */
-typedef enum { B_FALSE, B_TRUE } boolean_t;
+#endif
 typedef struct { dev_t dev; } xfs_buftarg_t;
+#undef MASK
+#define NBPP		getpagesize()
 #define STATIC
 #define ATTR_ROOT	0x0002	/* use attrs in root namespace */
-#define ENOATTR		ENODATA	/* Attribute not found */
-#define EFSCORRUPTED	990	/* Filesystem is corrupted */
 #define ktrace_t	void
 #define m_ddev_targp	m_dev
+#define unlikely(x)	(x)
 #define kdev_none(x)	(!(x))
+#define INIT_LIST_HEAD(x)
 #define KERN_WARNING
 #define XFS_ERROR(e)	(e)
+#define XFS_ERRLEVEL_LOW		1
+#define XFS_ERROR_REPORT(e,l,mp)	((void) 0)
+#define XFS_CORRUPTION_ERROR(e,l,mp,m)	((void) 0)
 #define XFS_TEST_ERROR(expr,a,b,c)	( expr )
 #define TRACE_FREE(s,a,b,x,f)		((void) 0)
 #define TRACE_ALLOC(s,a)		((void) 0)
 #define TRACE_MODAGF(a,b,c)		((void) 0)
 #define XFS_FORCED_SHUTDOWN(mp)		0
+#define XFS_STATS_INC(count)		do { } while (0)
+#define XFS_STATS_DEC(count, x)		do { } while (0)
+#define XFS_STATS_ADD(count, x)		do { } while (0)
 #define XFS_MOUNT_WSYNC			0	/* ignored in userspace */
 #define XFS_MOUNT_NOALIGN		0	/* ignored in userspace */
 #define XFS_MOUNT_32BITINODES		0x1	/* enforce in userspace */
@@ -262,17 +272,34 @@ typedef struct { dev_t dev; } xfs_buftarg_t;
 #define mraccess(a)			((void) 0)
 #define ismrlocked(a,b)			1
 #define spinlock_init(a,b)		((void) 0)
+#define spin_lock(a)			((void) 0)
+#define spin_unlock(a)			((void) 0)
 #define __return_address		__builtin_return_address(0)
 #define xfs_btree_reada_bufl(m,fsb,c)	((void) 0)
 #define xfs_btree_reada_bufs(m,fsb,c,x)	((void) 0)
 #undef  XFS_DIR_SHORTFORM_VALIDATE_ONDISK
 #define XFS_DIR_SHORTFORM_VALIDATE_ONDISK(mp,dip) 0
+#define XFS_TRANS_MOD_DQUOT_BYINO(mp,tp,ip,field,delta)
+#define XFS_TRANS_RESERVE_BLKQUOTA(mp,tp,ip,nblks)	0
+#define XFS_TRANS_UNRESERVE_BLKQUOTA(mp,tp,ip,nblks)
+#define XFS_TRANS_RESERVE_QUOTA_NBLKS(mp,tp,ip,nblks,ninos,fl)
+
+/* These are lifted from the kernel */
+#define get_unaligned(ptr) \
+  ({ __typeof__(*(ptr)) __tmp; memmove(&__tmp, (ptr), sizeof(*(ptr))); __tmp; })
+
+#define put_unaligned(val, ptr)			\
+  ({ __typeof__(*(ptr)) __tmp = (val);		\
+     memmove((ptr), &__tmp, sizeof(*(ptr)));	\
+     (void)0; })
 
 #if (__GNUC__ < 2) || ((__GNUC__ == 2) && (__GNUC_MINOR__ <= 95))
 # define xfs_fs_cmn_err(a,b,msg,args...)( fprintf(stderr, msg, ## args) )
+# define cmn_err(a,msg,args...)		( fprintf(stderr, msg, ## args) )
 # define printk(msg,args...)		( fprintf(stderr, msg, ## args) )
 #else
 # define xfs_fs_cmn_err(a,b,...)	( fprintf(stderr, __VA_ARGS__) )
+# define cmn_err(a,...)			( fprintf(stderr, __VA_ARGS__) )
 # define printk(...)			( fprintf(stderr, __VA_ARGS__) )
 #endif
 
@@ -283,9 +310,6 @@ typedef struct { dev_t dev; } xfs_buftarg_t;
 	n = ((unsigned long) n) / (unsigned) base; \
 	__res; })
 
-#include <asm/page.h>
-#define NBPP		PAGE_SIZE
-
 static inline int atomicIncWithWrap(int *a, int b)
 {
 	int r = *a;
@@ -374,7 +398,7 @@ int  xfs_ialloc (xfs_trans_t *, xfs_inode_t *, mode_t, nlink_t, dev_t, cred_t *,
 		xfs_prid_t, int, xfs_buf_t **, boolean_t *, xfs_inode_t **);
 int  xfs_iread_extents (xfs_trans_t *, xfs_inode_t *, int);
 int  xfs_imap (xfs_mount_t *, xfs_trans_t *, xfs_ino_t, xfs_imap_t *, uint);
-int  xfs_iextents_copy (xfs_inode_t *, xfs_bmbt_rec_32_t *, int);
+int  xfs_iextents_copy (xfs_inode_t *, xfs_bmbt_rec_t *, int);
 int  xfs_iflush_int (xfs_inode_t *, xfs_buf_t *);
 int  xfs_iflush_fork (xfs_inode_t *, xfs_dinode_t *, xfs_inode_log_item_t *,
 		int, xfs_buf_t *);
@@ -428,12 +452,48 @@ void xfs_bmap_insert_exlist (xfs_inode_t *, xfs_extnum_t, xfs_extnum_t,
 int  xfs_check_nostate_extents (xfs_bmbt_rec_t *, xfs_extnum_t);
 void xfs_bmbt_log_ptrs (xfs_btree_cur_t *, xfs_buf_t *, int, int);
 void xfs_bmbt_log_keys (xfs_btree_cur_t *, xfs_buf_t *, int, int);
-int  xfs_bmbt_killroot (xfs_btree_cur_t *, int);
+int  xfs_bmbt_newroot (xfs_btree_cur_t *, int *, int *);
+int  xfs_bmbt_killroot (xfs_btree_cur_t *);
 int  xfs_bmbt_updkey (xfs_btree_cur_t *, xfs_bmbt_key_t *, int);
 int  xfs_bmbt_lshift (xfs_btree_cur_t *, int, int *);
 int  xfs_bmbt_rshift (xfs_btree_cur_t *, int, int *);
 int  xfs_bmbt_split (xfs_btree_cur_t *, int, xfs_fsblock_t *,
 			xfs_bmbt_key_t *, xfs_btree_cur_t **, int *);
+void xfs_bmbt_set_all (xfs_bmbt_rec_t *, xfs_bmbt_irec_t *);
+void xfs_bmbt_set_allf (xfs_bmbt_rec_t *, xfs_fileoff_t, xfs_fsblock_t,
+			xfs_filblks_t, xfs_exntst_t);
+void xfs_bmbt_set_blockcount (xfs_bmbt_rec_t *, xfs_filblks_t);
+void xfs_bmbt_set_startblock (xfs_bmbt_rec_t *, xfs_fsblock_t);
+void xfs_bmbt_set_startoff (xfs_bmbt_rec_t *, xfs_fileoff_t);
+void xfs_bmbt_set_state (xfs_bmbt_rec_t *, xfs_exntst_t);
+void xfs_bmbt_log_block (struct xfs_btree_cur *, struct xfs_buf *, int);
+void xfs_bmbt_log_recs (struct xfs_btree_cur *, struct xfs_buf *, int, int);
+int  xfs_bmbt_lookup_eq (struct xfs_btree_cur *, xfs_fileoff_t, xfs_fsblock_t,
+			xfs_filblks_t, int *);
+xfs_fsblock_t xfs_bmbt_get_startblock (xfs_bmbt_rec_t *);
+xfs_filblks_t xfs_bmbt_get_blockcount (xfs_bmbt_rec_t *);
+xfs_fileoff_t xfs_bmbt_get_startoff (xfs_bmbt_rec_t *);
+xfs_exntst_t  xfs_bmbt_get_state (xfs_bmbt_rec_t *);
+xfs_bmbt_block_t * xfs_bmbt_get_block (xfs_btree_cur_t *, int,
+			struct xfs_buf **);
+int  xfs_bmbt_increment (struct xfs_btree_cur *, int, int *);
+int  xfs_bmbt_insert (struct xfs_btree_cur *, int *);
+int  xfs_bmbt_decrement (struct xfs_btree_cur *, int, int *);
+int  xfs_bmbt_delete (struct xfs_btree_cur *, int *);
+int  xfs_bmbt_update (struct xfs_btree_cur *, xfs_fileoff_t, xfs_fsblock_t,
+			xfs_filblks_t, xfs_exntst_t);
+void xfs_bmbt_to_bmdr (xfs_bmbt_block_t *, int, xfs_bmdr_block_t *, int);
+void xfs_bmdr_to_bmbt (xfs_bmdr_block_t *, int, xfs_bmbt_block_t *, int);
+#if ARCH_CONVERT != ARCH_NOCONVERT
+xfs_fileoff_t xfs_bmbt_disk_get_startoff (xfs_bmbt_rec_t *);
+void xfs_bmbt_disk_set_all (xfs_bmbt_rec_t *, xfs_bmbt_irec_t *);
+void xfs_bmbt_disk_set_allf (xfs_bmbt_rec_t *, xfs_fileoff_t, xfs_fsblock_t,
+			xfs_filblks_t, xfs_exntst_t);
+#else
+#define xfs_bmbt_disk_get_startoff(r) xfs_bmbt_get_startoff(r)
+#define xfs_bmbt_disk_set_all(r, s) xfs_bmbt_set_all(r, s)
+#define xfs_bmbt_disk_set_allf(r, o, b, c, v) xfs_bmbt_set_allf(r, o, b, c, v)
+#endif
 
 /* xfs_ialloc_btree.c */
 int  xfs_inobt_newroot (xfs_btree_cur_t *, int *);
