@@ -11,7 +11,7 @@
  *
  * Further, this software is distributed without any warranty that it is
  * free of the rightful claim of any third person regarding infringement
- * or the like.	 Any license provided herein, whether implied or
+ * or the like.  Any license provided herein, whether implied or
  * otherwise, applies only to this software file.  Patent licenses, if
  * any, provided herein do not apply to combinations of this program with
  * other software, or any other product whatsoever.
@@ -38,6 +38,7 @@
  * Routines to implement directories as Btrees of hashed names.
  */
 
+static int xfs_error_level;
 
 /*========================================================================
  * Routines used for growing the Btree.
@@ -331,12 +332,16 @@ xfs_da_root_split(xfs_da_state_t *state, xfs_da_state_blk_t *blk1,
 	INT_SET(node->btree[1].hashval, ARCH_CONVERT, blk2->hashval);
 	INT_SET(node->btree[1].before, ARCH_CONVERT, blk2->blkno);
 	INT_SET(node->hdr.count, ARCH_CONVERT, 2);
-	if (XFS_DIR_IS_V2(mp)) {
+
+#ifdef DEBUG
+	if (INT_GET(oldroot->hdr.info.magic, ARCH_CONVERT) == XFS_DIR2_LEAFN_MAGIC) {
 		ASSERT(blk1->blkno >= mp->m_dirleafblk &&
 		       blk1->blkno < mp->m_dirfreeblk);
 		ASSERT(blk2->blkno >= mp->m_dirleafblk &&
 		       blk2->blkno < mp->m_dirfreeblk);
 	}
+#endif
+
 	/* Header is already logged by xfs_da_node_create */
 	xfs_da_log_buf(tp, bp,
 		XFS_DA_LOGRANGE(node, node->btree,
@@ -371,7 +376,7 @@ xfs_da_node_split(xfs_da_state_t *state, xfs_da_state_blk_t *oldblk,
 	/*
 	 * Do we have to split the node?
 	 */
-	if ((INT_GET(node->hdr.count, ARCH_CONVERT) + newcount) > XFS_DA_NODE_ENTRIES(state->mp)) {
+	if ((INT_GET(node->hdr.count, ARCH_CONVERT) + newcount) > state->node_ents) {
 		/*
 		 * Allocate a new node, add to the doubly linked chain of
 		 * nodes, then move some of our excess entries into it.
@@ -692,7 +697,7 @@ xfs_da_join(xfs_da_state_t *state)
 }
 
 /*
- * We have only one entry in the root.	Copy the only remaining child of
+ * We have only one entry in the root.  Copy the only remaining child of
  * the old root to block 0 as the new root node.
  */
 STATIC int
@@ -775,9 +780,9 @@ xfs_da_node_toosmall(xfs_da_state_t *state, int *action)
 	ASSERT(INT_GET(info->magic, ARCH_CONVERT) == XFS_DA_NODE_MAGIC);
 	node = (xfs_da_intnode_t *)info;
 	count = INT_GET(node->hdr.count, ARCH_CONVERT);
-	if (count > (XFS_DA_NODE_ENTRIES(state->mp) >> 1)) {
-		*action = 0;	/* blk over 50%, dont try to join */
-		return(0);	/* blk over 50%, dont try to join */
+	if (count > (state->node_ents >> 1)) {
+		*action = 0;	/* blk over 50%, don't try to join */
+		return(0);	/* blk over 50%, don't try to join */
 	}
 
 	/*
@@ -829,8 +834,8 @@ xfs_da_node_toosmall(xfs_da_state_t *state, int *action)
 		ASSERT(bp != NULL);
 
 		node = (xfs_da_intnode_t *)info;
-		count  = XFS_DA_NODE_ENTRIES(state->mp);
-		count -= XFS_DA_NODE_ENTRIES(state->mp) >> 2;
+		count  = state->node_ents;
+		count -= state->node_ents >> 2;
 		count -= INT_GET(node->hdr.count, ARCH_CONVERT);
 		node = bp->data;
 		ASSERT(INT_GET(node->hdr.info.magic, ARCH_CONVERT) == XFS_DA_NODE_MAGIC);
@@ -874,7 +879,6 @@ xfs_da_node_toosmall(xfs_da_state_t *state, int *action)
 	return(0);
 }
 
-
 /*
  * Walk back up the tree adjusting hash values as necessary,
  * when we stop making changes, return.
@@ -931,8 +935,6 @@ xfs_da_fixhashpath(xfs_da_state_t *state, xfs_da_state_path_t *path)
 	}
 }
 
-
-
 /*
  * Remove an entry from an intermediate node.
  */
@@ -1033,7 +1035,6 @@ xfs_da_node_unbalance(xfs_da_state_t *state, xfs_da_state_blk_t *drop_blk,
 	save_blk->hashval = INT_GET(save_node->btree[ INT_GET(save_node->hdr.count, ARCH_CONVERT)-1 ].hashval, ARCH_CONVERT);
 }
 
-
 /*========================================================================
  * Routines used for finding things in the Btree.
  *========================================================================*/
@@ -1203,7 +1204,6 @@ xfs_da_node_lookup_int(xfs_da_state_t *state, int *result)
 	return(0);
 }
 
-
 /*========================================================================
  * Utility routines.
  *========================================================================*/
@@ -1308,7 +1308,6 @@ xfs_da_blk_link(xfs_da_state_t *state, xfs_da_state_blk_t *old_blk,
 	return(0);
 }
 
-
 /*
  * Compare two intermediate nodes for "order".
  */
@@ -1331,7 +1330,6 @@ xfs_da_node_order(xfs_dabuf_t *node1_bp, xfs_dabuf_t *node2_bp)
 	return(0);
 }
 
-
 /*
  * Pick up the last hashvalue from an intermediate node.
  */
@@ -1555,7 +1553,7 @@ xfs_da_hashname(uchar_t *name, int namelen)
 {
 	xfs_dahash_t hash;
 
-#define ROTL(x,y)	(((x) << (y)) | ((x) >> (32 - (y))))
+#define	ROTL(x,y)	(((x) << (y)) | ((x) >> (32 - (y))))
 #ifdef SLOWVERSION
 	/*
 	 * This is the old one-byte-at-a-time version.
@@ -1601,7 +1599,7 @@ xfs_da_grow_inode(xfs_da_args_t *args, xfs_dablk_t *new_blkno)
 {
 	xfs_fileoff_t bno, b;
 	xfs_bmbt_irec_t map;
-	xfs_bmbt_irec_t *mapp;
+	xfs_bmbt_irec_t	*mapp;
 	xfs_inode_t *dp;
 	int nmap, error, w, count, c, got, i, mapi;
 	xfs_fsize_t size;
@@ -1649,7 +1647,7 @@ xfs_da_grow_inode(xfs_da_args_t *args, xfs_dablk_t *new_blkno)
 	}
 	/*
 	 * If we didn't get it and the block might work if fragmented,
-	 * try without the CONTIG flag.	 Loop until we get it all.
+	 * try without the CONTIG flag.  Loop until we get it all.
 	 */
 	else if (nmap == 0 && count > 1) {
 		mapp = kmem_alloc(sizeof(*mapp) * count, KM_SLEEP);
@@ -1705,9 +1703,8 @@ xfs_da_grow_inode(xfs_da_args_t *args, xfs_dablk_t *new_blkno)
 	return 0;
 }
 
-
 /*
- * Ick.	 We need to always be able to remove a btree block, even
+ * Ick.  We need to always be able to remove a btree block, even
  * if there's no space reservation because the filesystem is full.
  * This is called if xfs_bunmapi on a btree block fails due to ENOSPC.
  * It swaps the target block with the last block in the file.  The
@@ -1745,8 +1742,11 @@ xfs_da_swap_lastblock(xfs_da_args_t *args, xfs_dablk_t *dead_blknop,
 		error = xfs_bmap_last_offset(tp, ip, &lastoff, w);
 	if (error)
 		return error;
-	if (lastoff == 0)
+	if (unlikely(lastoff == 0)) {
+		XFS_ERROR_REPORT("xfs_da_swap_lastblock(1)", XFS_ERRLEVEL_LOW,
+				 mp);
 		return XFS_ERROR(EFSCORRUPTED);
+	}
 	/*
 	 * Read the last block in the btree space.
 	 */
@@ -1787,8 +1787,11 @@ xfs_da_swap_lastblock(xfs_da_args_t *args, xfs_dablk_t *dead_blknop,
 		if ((error = xfs_da_read_buf(tp, ip, sib_blkno, -1, &sib_buf, w)))
 			goto done;
 		sib_info = sib_buf->data;
-		if (INT_GET(sib_info->forw, ARCH_CONVERT) != last_blkno ||
-		    INT_GET(sib_info->magic, ARCH_CONVERT) != INT_GET(dead_info->magic, ARCH_CONVERT)) {
+		if (unlikely(
+		    INT_GET(sib_info->forw, ARCH_CONVERT) != last_blkno ||
+		    INT_GET(sib_info->magic, ARCH_CONVERT) != INT_GET(dead_info->magic, ARCH_CONVERT))) {
+			XFS_ERROR_REPORT("xfs_da_swap_lastblock(2)",
+					 XFS_ERRLEVEL_LOW, mp);
 			error = XFS_ERROR(EFSCORRUPTED);
 			goto done;
 		}
@@ -1806,9 +1809,12 @@ xfs_da_swap_lastblock(xfs_da_args_t *args, xfs_dablk_t *dead_blknop,
 		if ((error = xfs_da_read_buf(tp, ip, sib_blkno, -1, &sib_buf, w)))
 			goto done;
 		sib_info = sib_buf->data;
-		if (   INT_GET(sib_info->back, ARCH_CONVERT) != last_blkno
+		if (unlikely(
+		       INT_GET(sib_info->back, ARCH_CONVERT) != last_blkno
 		    || INT_GET(sib_info->magic, ARCH_CONVERT)
-				!= INT_GET(dead_info->magic, ARCH_CONVERT)) {
+				!= INT_GET(dead_info->magic, ARCH_CONVERT))) {
+			XFS_ERROR_REPORT("xfs_da_swap_lastblock(3)",
+					 XFS_ERRLEVEL_LOW, mp);
 			error = XFS_ERROR(EFSCORRUPTED);
 			goto done;
 		}
@@ -1828,8 +1834,11 @@ xfs_da_swap_lastblock(xfs_da_args_t *args, xfs_dablk_t *dead_blknop,
 		if ((error = xfs_da_read_buf(tp, ip, par_blkno, -1, &par_buf, w)))
 			goto done;
 		par_node = par_buf->data;
-		if (INT_GET(par_node->hdr.info.magic, ARCH_CONVERT) != XFS_DA_NODE_MAGIC ||
-		    (level >= 0 && level != INT_GET(par_node->hdr.level, ARCH_CONVERT) + 1)) {
+		if (unlikely(
+		    INT_GET(par_node->hdr.info.magic, ARCH_CONVERT) != XFS_DA_NODE_MAGIC ||
+		    (level >= 0 && level != INT_GET(par_node->hdr.level, ARCH_CONVERT) + 1))) {
+			XFS_ERROR_REPORT("xfs_da_swap_lastblock(4)",
+					 XFS_ERRLEVEL_LOW, mp);
 			error = XFS_ERROR(EFSCORRUPTED);
 			goto done;
 		}
@@ -1839,7 +1848,9 @@ xfs_da_swap_lastblock(xfs_da_args_t *args, xfs_dablk_t *dead_blknop,
 		     INT_GET(par_node->btree[entno].hashval, ARCH_CONVERT) < dead_hash;
 		     entno++)
 			continue;
-		if (entno == INT_GET(par_node->hdr.count, ARCH_CONVERT)) {
+		if (unlikely(entno == INT_GET(par_node->hdr.count, ARCH_CONVERT))) {
+			XFS_ERROR_REPORT("xfs_da_swap_lastblock(5)",
+					 XFS_ERRLEVEL_LOW, mp);
 			error = XFS_ERROR(EFSCORRUPTED);
 			goto done;
 		}
@@ -1864,15 +1875,20 @@ xfs_da_swap_lastblock(xfs_da_args_t *args, xfs_dablk_t *dead_blknop,
 		par_blkno = INT_GET(par_node->hdr.info.forw, ARCH_CONVERT);
 		xfs_da_brelse(tp, par_buf);
 		par_buf = NULL;
-		if (par_blkno == 0) {
+		if (unlikely(par_blkno == 0)) {
+			XFS_ERROR_REPORT("xfs_da_swap_lastblock(6)",
+					 XFS_ERRLEVEL_LOW, mp);
 			error = XFS_ERROR(EFSCORRUPTED);
 			goto done;
 		}
 		if ((error = xfs_da_read_buf(tp, ip, par_blkno, -1, &par_buf, w)))
 			goto done;
 		par_node = par_buf->data;
-		if (INT_GET(par_node->hdr.level, ARCH_CONVERT) != level ||
-		    INT_GET(par_node->hdr.info.magic, ARCH_CONVERT) != XFS_DA_NODE_MAGIC) {
+		if (unlikely(
+		    INT_GET(par_node->hdr.level, ARCH_CONVERT) != level ||
+		    INT_GET(par_node->hdr.info.magic, ARCH_CONVERT) != XFS_DA_NODE_MAGIC)) {
+			XFS_ERROR_REPORT("xfs_da_swap_lastblock(7)",
+					 XFS_ERRLEVEL_LOW, mp);
 			error = XFS_ERROR(EFSCORRUPTED);
 			goto done;
 		}
@@ -1967,7 +1983,7 @@ done:
 STATIC int
 xfs_da_map_covers_blocks(
 	int		nmap,
-	xfs_bmbt_irec_t *mapp,
+	xfs_bmbt_irec_t	*mapp,
 	xfs_dablk_t	bno,
 	int		count)
 {
@@ -2006,8 +2022,8 @@ xfs_da_do_buf(
 	xfs_buf_t	**bplist;
 	int		error=0;
 	int		i;
-	xfs_bmbt_irec_t map;
-	xfs_bmbt_irec_t *mapp;
+	xfs_bmbt_irec_t	map;
+	xfs_bmbt_irec_t	*mapp;
 	xfs_daddr_t	mappedbno;
 	xfs_mount_t	*mp;
 	int		nbplist=0;
@@ -2065,6 +2081,26 @@ xfs_da_do_buf(
 	}
 	if (!xfs_da_map_covers_blocks(nmap, mapp, bno, nfsb)) {
 		error = mappedbno == -2 ? 0 : XFS_ERROR(EFSCORRUPTED);
+		if (unlikely(error == EFSCORRUPTED)) {
+			if (xfs_error_level >= XFS_ERRLEVEL_LOW) {
+				int	i;
+				cmn_err(CE_ALERT, "xfs_da_do_buf: bno %lld\n",
+					(long long)bno);
+				cmn_err(CE_ALERT, "dir: inode %lld\n",
+					(long long)dp->i_ino);
+				for (i = 0; i < nmap; i++) {
+					cmn_err(CE_ALERT,
+						"[%02d] br_startoff %lld br_startblock %lld br_blockcount %lld br_state %d\n",
+						i,
+						mapp[i].br_startoff,
+						mapp[i].br_startblock,
+						mapp[i].br_blockcount,
+						mapp[i].br_state);
+				}
+			}
+			XFS_ERROR_REPORT("xfs_da_do_buf(1)",
+					 XFS_ERRLEVEL_LOW, mp);
+		}
 		goto exit0;
 	}
 	if (caller != 3 && nmap > 1) {
@@ -2147,7 +2183,8 @@ xfs_da_do_buf(
 		free = rbp->data;
 		magic = INT_GET(info->magic, ARCH_CONVERT);
 		magic1 = INT_GET(data->hdr.magic, ARCH_CONVERT);
-		if (XFS_TEST_ERROR((magic != XFS_DA_NODE_MAGIC) &&
+		if (unlikely(
+		    XFS_TEST_ERROR((magic != XFS_DA_NODE_MAGIC) &&
 				   (magic != XFS_DIR_LEAF_MAGIC) &&
 				   (magic != XFS_ATTR_LEAF_MAGIC) &&
 				   (magic != XFS_DIR2_LEAF1_MAGIC) &&
@@ -2156,8 +2193,10 @@ xfs_da_do_buf(
 				   (magic1 != XFS_DIR2_DATA_MAGIC) &&
 				   (INT_GET(free->hdr.magic, ARCH_CONVERT) != XFS_DIR2_FREE_MAGIC),
 				mp, XFS_ERRTAG_DA_READ_BUF,
-				XFS_RANDOM_DA_READ_BUF)) {
+				XFS_RANDOM_DA_READ_BUF))) {
 			xfs_buftrace("DA READ ERROR", rbp->bps[0]);
+			XFS_CORRUPTION_ERROR("xfs_da_do_buf(2)",
+					     XFS_ERRLEVEL_LOW, mp, info);
 			error = XFS_ERROR(EFSCORRUPTED);
 			xfs_da_brelse(trans, rbp);
 			nbplist = 0;
