@@ -11,7 +11,7 @@
  *
  * Further, this software is distributed without any warranty that it is
  * free of the rightful claim of any third person regarding infringement
- * or the like.	 Any license provided herein, whether implied or
+ * or the like.  Any license provided herein, whether implied or
  * otherwise, applies only to this software file.  Patent licenses, if
  * any, provided herein do not apply to combinations of this program with
  * other software, or any other product whatsoever.
@@ -32,6 +32,7 @@
 
 #include <xfs.h>
 
+
 /*
  * xfs_dir.c
  *
@@ -68,7 +69,7 @@ xfs_dir_mount(xfs_mount_t *mp)
 	count = shortcount > leafcount ? shortcount : leafcount;
 	mp->m_dircook_elog = xfs_da_log2_roundup(count + 1);
 	ASSERT(mp->m_dircook_elog <= mp->m_sb.sb_blocklog);
-	mp->m_da_node_ents =
+	mp->m_dir_node_ents = mp->m_attr_node_ents =
 		(XFS_LBSIZE(mp) - (uint)sizeof(xfs_da_node_hdr_t)) /
 		(uint)sizeof(xfs_da_node_entry_t);
 	mp->m_dir_magicpct = (XFS_LBSIZE(mp) * 37) / 100;
@@ -218,9 +219,6 @@ xfs_dir_lookup(xfs_trans_t *trans, xfs_inode_t *dp, char *name, int namelen,
 	int retval;
 
 	ASSERT((dp->i_d.di_mode & IFMT) == IFDIR);
-	if (namelen >= MAXNAMELEN) {
-		return(XFS_ERROR(EINVAL));
-	}
 
 	XFS_STATS_INC(xfsstats.xs_dir_lookup);
 	/*
@@ -264,9 +262,6 @@ xfs_dir_replace(xfs_trans_t *trans, xfs_inode_t *dp, char *name, int namelen,
 	int retval;
 
 	ASSERT((dp->i_d.di_mode & IFMT) == IFDIR);
-	if (namelen >= MAXNAMELEN) {
-		return(XFS_ERROR(EINVAL));
-	}
 
 	if ((retval = xfs_dir_ino_validate(trans->t_mountp, inum)))
 		return retval;
@@ -439,6 +434,7 @@ xfs_dir_node_addname(xfs_da_args_t *args)
 	state->args = args;
 	state->mp = args->dp->i_mount;
 	state->blocksize = state->mp->m_sb.sb_blocksize;
+	state->node_ents = state->mp->m_dir_node_ents;
 
 	/*
 	 * Search to see if name already exists, and get back a pointer
@@ -492,6 +488,7 @@ xfs_dir_node_removename(xfs_da_args_t *args)
 	state->args = args;
 	state->mp = args->dp->i_mount;
 	state->blocksize = state->mp->m_sb.sb_blocksize;
+	state->node_ents = state->mp->m_dir_node_ents;
 
 	/*
 	 * Search to see if name exists, and get back a pointer to it.
@@ -540,6 +537,7 @@ xfs_dir_node_lookup(xfs_da_args_t *args)
 	state->args = args;
 	state->mp = args->dp->i_mount;
 	state->blocksize = state->mp->m_sb.sb_blocksize;
+	state->node_ents = state->mp->m_dir_node_ents;
 
 	/*
 	 * Search to see if name exists,
@@ -582,6 +580,7 @@ xfs_dir_node_replace(xfs_da_args_t *args)
 	state->args = args;
 	state->mp = args->dp->i_mount;
 	state->blocksize = state->mp->m_sb.sb_blocksize;
+	state->node_ents = state->mp->m_dir_node_ents;
 	inum = args->inumber;
 
 	/*
