@@ -11,7 +11,7 @@
  *
  * Further, this software is distributed without any warranty that it is
  * free of the rightful claim of any third person regarding infringement
- * or the like.	 Any license provided herein, whether implied or
+ * or the like.  Any license provided herein, whether implied or
  * otherwise, applies only to this software file.  Patent licenses, if
  * any, provided herein do not apply to combinations of this program with
  * other software, or any other product whatsoever.
@@ -312,7 +312,7 @@ xfs_dir2_leafn_check(
 	xfs_dabuf_t	*bp)			/* leaf buffer */
 {
 	int		i;			/* leaf index */
-	xfs_dir2_leaf_t *leaf;			/* leaf structure */
+	xfs_dir2_leaf_t	*leaf;			/* leaf structure */
 	xfs_mount_t	*mp;			/* filesystem mount point */
 	int		stale;			/* count of stale leaves */
 
@@ -341,7 +341,7 @@ xfs_dir2_leafn_lasthash(
 	xfs_dabuf_t	*bp,			/* leaf buffer */
 	int		*count)			/* count of entries in leaf */
 {
-	xfs_dir2_leaf_t *leaf;			/* leaf structure */
+	xfs_dir2_leaf_t	*leaf;			/* leaf structure */
 
 	leaf = bp->data;
 	ASSERT(INT_GET(leaf->hdr.info.magic, ARCH_CONVERT) == XFS_DIR2_LEAFN_MAGIC);
@@ -489,7 +489,9 @@ xfs_dir2_leafn_lookup_int(
 				/*
 				 * If it has room, return it.
 				 */
-				if (INT_GET(free->bests[fi], ARCH_CONVERT) == NULLDATAOFF) {
+				if (unlikely(INT_GET(free->bests[fi], ARCH_CONVERT) == NULLDATAOFF)) {
+					XFS_ERROR_REPORT("xfs_dir2_leafn_lookup_int",
+							 XFS_ERRLEVEL_LOW, mp);
 					return XFS_ERROR(EFSCORRUPTED);
 				}
 				if (INT_GET(free->bests[fi], ARCH_CONVERT) >= length) {
@@ -600,8 +602,8 @@ xfs_dir2_leafn_moveents(
 	int		start_d,		/* destination leaf index */
 	int		count)			/* count of leaves to copy */
 {
-	xfs_dir2_leaf_t *leaf_d;		/* destination leaf structure */
-	xfs_dir2_leaf_t *leaf_s;		/* source leaf structure */
+	xfs_dir2_leaf_t	*leaf_d;		/* destination leaf structure */
+	xfs_dir2_leaf_t	*leaf_s;		/* source leaf structure */
 	int		stale;			/* count stale leaves copied */
 	xfs_trans_t	*tp;			/* transaction pointer */
 
@@ -678,8 +680,8 @@ xfs_dir2_leafn_order(
 	xfs_dabuf_t	*leaf1_bp,		/* leaf1 buffer */
 	xfs_dabuf_t	*leaf2_bp)		/* leaf2 buffer */
 {
-	xfs_dir2_leaf_t *leaf1;			/* leaf1 structure */
-	xfs_dir2_leaf_t *leaf2;			/* leaf2 structure */
+	xfs_dir2_leaf_t	*leaf1;			/* leaf1 structure */
+	xfs_dir2_leaf_t	*leaf2;			/* leaf2 structure */
 
 	leaf1 = leaf1_bp->data;
 	leaf2 = leaf2_bp->data;
@@ -758,7 +760,7 @@ xfs_dir2_leafn_rebalance(
 	else
 		isleft = 1;
 	/*
-	 * Calculate moved entry count.	 Positive means left-to-right,
+	 * Calculate moved entry count.  Positive means left-to-right,
 	 * negative means right-to-left.  Then move the entries.
 	 */
 	count = INT_GET(leaf1->hdr.count, ARCH_CONVERT) - mid + (isleft == 0);
@@ -868,7 +870,7 @@ xfs_dir2_leafn_remove(
 		xfs_dabuf_t	*fbp;		/* freeblock buffer */
 		xfs_dir2_db_t	fdb;		/* freeblock block number */
 		int		findex;		/* index in freeblock entries */
-		xfs_dir2_free_t *free;		/* freeblock structure */
+		xfs_dir2_free_t	*free;		/* freeblock structure */
 		int		logfree;	/* need to log free entry */
 
 		/*
@@ -1252,6 +1254,7 @@ xfs_dir2_node_addname(
 	state->args = args;
 	state->mp = args->dp->i_mount;
 	state->blocksize = state->mp->m_dirblksize;
+	state->node_ents = state->mp->m_dir_node_ents;
 	/*
 	 * Look up the name.  We're not supposed to find it, but
 	 * this gives us the insertion point.
@@ -1301,7 +1304,6 @@ done:
 	return rval;
 }
 
-
 /*
  * Add the data entry for a node-format directory name addition.
  * The leaf entry is added in xfs_dir2_leafn_add.
@@ -1324,6 +1326,7 @@ xfs_dir2_node_addname_int(
 	int			findex;		/* freespace entry index */
 	xfs_dir2_db_t		foundbno=0;	/* found freespace block no */
 	int			foundindex=0;	/* found freespace entry idx */
+	int			foundhole;	/* found hole in freespace */
 	xfs_dir2_free_t		*free=NULL;	/* freespace block structure */
 	xfs_dir2_db_t		ifbno;		/* initial freespace block no */
 	xfs_dir2_db_t		lastfbno=0;	/* highest freespace block no */
@@ -1332,6 +1335,7 @@ xfs_dir2_node_addname_int(
 	xfs_mount_t		*mp;		/* filesystem mount point */
 	int			needlog;	/* need to log data header */
 	int			needscan;	/* need to rescan data frees */
+	int			needfreesp;	/* need to allocate freesp blk */
 	xfs_dir2_data_off_t	*tagp;		/* data entry tag pointer */
 	xfs_trans_t		*tp;		/* transaction pointer */
 
@@ -1339,9 +1343,10 @@ xfs_dir2_node_addname_int(
 	mp = dp->i_mount;
 	tp = args->trans;
 	length = XFS_DIR2_DATA_ENTSIZE(args->namelen);
+	foundhole = 0;
 	/*
 	 * If we came in with a freespace block that means that lookup
-	 * found an entry with our hash value.	This is the freespace
+	 * found an entry with our hash value.  This is the freespace
 	 * block for that data entry.
 	 */
 	if (fblk) {
@@ -1397,7 +1402,7 @@ xfs_dir2_node_addname_int(
 	}
 	/*
 	 * While we haven't identified a data block, search the freeblock
-	 * data for a good data block.	If we find a null freeblock entry,
+	 * data for a good data block.  If we find a null freeblock entry,
 	 * indicating a hole in the data blocks, remember that.
 	 */
 	while (dbno == -1) {
@@ -1428,11 +1433,12 @@ xfs_dir2_node_addname_int(
 			 * to avoid it.
 			 */
 			if ((error = xfs_da_read_buf(tp, dp,
-					XFS_DIR2_DB_TO_DA(mp, fbno), -1, &fbp,
+					XFS_DIR2_DB_TO_DA(mp, fbno), -2, &fbp,
 					XFS_DATA_FORK))) {
 				return error;
 			}
-			if (fbp == NULL) {
+			if (unlikely(fbp == NULL)) {
+				foundhole = 1;
 				continue;
 			}
 			free = fbp->data;
@@ -1451,7 +1457,7 @@ xfs_dir2_node_addname_int(
 			 * one is empty, remember this slot.
 			 */
 			if (foundindex == -1 &&
-			    INT_GET(free->bests[findex], ARCH_CONVERT) == NULLDATAOFF) {
+			    INT_GET(free->bests[findex], ARCH_CONVERT) == NULLDATAOFF && !foundhole) {
 				foundindex = findex;
 				foundbno = fbno;
 			}
@@ -1465,7 +1471,8 @@ xfs_dir2_node_addname_int(
 				 * remember this slot.
 				 */
 				if (foundindex == -1 &&
-				    findex < XFS_DIR2_MAX_FREE_BESTS(mp)) {
+				    findex < XFS_DIR2_MAX_FREE_BESTS(mp) &&
+				    !foundhole) {
 					foundindex = findex;
 					foundbno = fbno;
 				}
@@ -1479,69 +1486,11 @@ xfs_dir2_node_addname_int(
 			}
 		}
 	}
-	/*
-	 * If we don't have a data block, and there's no free slot in a
-	 * freeblock, we need to add a new freeblock.
-	 */
-	if (dbno == -1 && foundindex == -1) {
-		/*
-		 * Not allowed to allocate, so return failure.
-		 */
-		if (args->justcheck || args->total == 0) {
-			return XFS_ERROR(ENOSPC);
-		}
-		/*
-		 * Add the new freeblock.
-		 */
-		if ((error = xfs_dir2_grow_inode(args, XFS_DIR2_FREE_SPACE,
-				&fbno))) {
-			return error;
-		}
-		/*
-		 * Get a buffer for the new block.
-		 */
-		if ((error = xfs_da_get_buf(tp, dp, XFS_DIR2_DB_TO_DA(mp, fbno),
-				-1, &fbp, XFS_DATA_FORK))) {
-			return error;
-		}
-		ASSERT(fbp != NULL);
-		/*
-		 * Initialize the new block to be empty, and remember
-		 * its first slot as our empty slot.
-		 */
-		free = fbp->data;
-		INT_SET(free->hdr.magic, ARCH_CONVERT, XFS_DIR2_FREE_MAGIC);
-		INT_SET(free->hdr.firstdb, ARCH_CONVERT, (fbno - XFS_DIR2_FREE_FIRSTDB(mp)) *
-			XFS_DIR2_MAX_FREE_BESTS(mp));
-		INT_ZERO(free->hdr.nused, ARCH_CONVERT);
-		INT_ZERO(free->hdr.nvalid, ARCH_CONVERT);
-		foundindex = 0;
-		foundbno = fbno;
-	}
-	/*
-	 * If we don't have a data block, and we don't have a freeblock buffer
-	 * in hand (we dropped the one with the free slot in it),
-	 * go read the freeblock again.
-	 */
-	if (dbno == -1 && fbp == NULL) {
-		/*
-		 * We're going to use the empty slot we found before.
-		 */
-		findex = foundindex;
-		fbno = foundbno;
-		if ((error = xfs_da_read_buf(tp, dp, XFS_DIR2_DB_TO_DA(mp, fbno),
-				-1, &fbp, XFS_DATA_FORK))) {
-			return error;
-		}
-		ASSERT(fbp != NULL);
-		free = fbp->data;
-		ASSERT(INT_GET(free->hdr.magic, ARCH_CONVERT) == XFS_DIR2_FREE_MAGIC);
-	}
 	/*
 	 * If we don't have a data block, we need to allocate one and make
 	 * the freespace entries refer to it.
 	 */
-	if (dbno == -1) {
+	if (unlikely(dbno == -1)) {
 		/*
 		 * Not allowed to allocate, return failure.
 		 */
@@ -1550,7 +1499,7 @@ xfs_dir2_node_addname_int(
 			 * Drop the freespace buffer unless it came from our
 			 * caller.
 			 */
-			if (fblk == NULL || fblk->bp == NULL)
+			if ((fblk == NULL || fblk->bp == NULL) && fbp != NULL)
 				xfs_da_buf_done(fbp);
 			return XFS_ERROR(ENOSPC);
 		}
@@ -1564,7 +1513,7 @@ xfs_dir2_node_addname_int(
 			 * Drop the freespace buffer unless it came from our
 			 * caller.
 			 */
-			if (fblk == NULL || fblk->bp == NULL)
+			if ((fblk == NULL || fblk->bp == NULL) && fbp != NULL)
 				xfs_da_buf_done(fbp);
 			return error;
 		}
@@ -1573,21 +1522,81 @@ xfs_dir2_node_addname_int(
 		 * freespace block we have in hand, drop the one we have
 		 * and get the right one.
 		 */
-		if (XFS_DIR2_DB_TO_FDB(mp, dbno) != fbno) {
-			xfs_da_brelse(tp, fbp);
+		needfreesp = 0;
+		if (XFS_DIR2_DB_TO_FDB(mp, dbno) != fbno || fbp == NULL) {
+			if (fbp)
+				xfs_da_brelse(tp, fbp);
 			if (fblk && fblk->bp)
 				fblk->bp = NULL;
 			fbno = XFS_DIR2_DB_TO_FDB(mp, dbno);
 			if ((error = xfs_da_read_buf(tp, dp,
-					XFS_DIR2_DB_TO_DA(mp, fbno), -1, &fbp,
+					XFS_DIR2_DB_TO_DA(mp, fbno), -2, &fbp,
 					XFS_DATA_FORK))) {
 				xfs_da_buf_done(dbp);
 				return error;
 			}
-			ASSERT(fbp != NULL);
-			free = fbp->data;
-			ASSERT(INT_GET(free->hdr.magic, ARCH_CONVERT) == XFS_DIR2_FREE_MAGIC);
+
+			/*
+			 * If there wasn't a freespace block, the read will
+			 * return a NULL fbp.  Allocate one later.
+			 */
+
+			if(unlikely( fbp == NULL )) {
+				needfreesp = 1;
+			} else {
+				free = fbp->data;
+				ASSERT(INT_GET(free->hdr.magic, ARCH_CONVERT) == XFS_DIR2_FREE_MAGIC);
+			}
 		}
+
+		/*
+		 * If we don't have a data block, and there's no free slot in a
+		 * freeblock, we need to add a new freeblock.
+		 */
+		if (unlikely(needfreesp || foundindex == -1)) {
+			/*
+			 * Add the new freeblock.
+			 */
+			if ((error = xfs_dir2_grow_inode(args, XFS_DIR2_FREE_SPACE,
+							&fbno))) {
+				return error;
+			}
+
+			if (XFS_DIR2_DB_TO_FDB(mp, dbno) != fbno) {
+				cmn_err(CE_ALERT,
+		"xfs_dir2_node_addname_int: needed block %lld, got %lld\n",
+					(long long)XFS_DIR2_DB_TO_FDB(mp, dbno),
+					(long long)fbno);
+				XFS_ERROR_REPORT("xfs_dir2_node_addname_int",
+						 XFS_ERRLEVEL_LOW, mp);
+				return XFS_ERROR(EFSCORRUPTED);
+			}
+
+			/*
+			 * Get a buffer for the new block.
+			 */
+			if ((error = xfs_da_get_buf(tp, dp,
+						   XFS_DIR2_DB_TO_DA(mp, fbno),
+						   -1, &fbp, XFS_DATA_FORK))) {
+				return error;
+			}
+			ASSERT(fbp != NULL);
+
+			/*
+			 * Initialize the new block to be empty, and remember
+			 * its first slot as our empty slot.
+			 */
+			free = fbp->data;
+			INT_SET(free->hdr.magic, ARCH_CONVERT, XFS_DIR2_FREE_MAGIC);
+			INT_SET(free->hdr.firstdb, ARCH_CONVERT,
+				(fbno - XFS_DIR2_FREE_FIRSTDB(mp)) *
+				XFS_DIR2_MAX_FREE_BESTS(mp));
+			INT_ZERO(free->hdr.nvalid, ARCH_CONVERT);
+			INT_ZERO(free->hdr.nused, ARCH_CONVERT);
+			foundindex = 0;
+			foundbno = fbno;
+		}
+
 		/*
 		 * Set the freespace block index from the data block number.
 		 */
@@ -1629,16 +1638,17 @@ xfs_dir2_node_addname_int(
 		 * If just checking, we succeeded.
 		 */
 		if (args->justcheck) {
-			if (fblk == NULL || fblk->bp == NULL)
+			if ((fblk == NULL || fblk->bp == NULL) && fbp != NULL)
 				xfs_da_buf_done(fbp);
 			return 0;
 		}
 		/*
 		 * Read the data block in.
 		 */
-		if ((error = xfs_da_read_buf(tp, dp, XFS_DIR2_DB_TO_DA(mp, dbno),
+		if (unlikely(
+		    error = xfs_da_read_buf(tp, dp, XFS_DIR2_DB_TO_DA(mp, dbno),
 				-1, &dbp, XFS_DATA_FORK))) {
-			if (fblk == NULL || fblk->bp == NULL)
+			if ((fblk == NULL || fblk->bp == NULL) && fbp != NULL)
 				xfs_da_buf_done(fbp);
 			return error;
 		}
@@ -1693,7 +1703,7 @@ xfs_dir2_node_addname_int(
 	/*
 	 * If the caller didn't hand us the freespace block, drop it.
 	 */
-	if (fblk == NULL || fblk->bp == NULL)
+	if ((fblk == NULL || fblk->bp == NULL) && fbp != NULL)
 		xfs_da_buf_done(fbp);
 	/*
 	 * Return the data block and offset in args, then drop the data block.
@@ -1726,6 +1736,7 @@ xfs_dir2_node_lookup(
 	state->args = args;
 	state->mp = args->dp->i_mount;
 	state->blocksize = state->mp->m_dirblksize;
+	state->node_ents = state->mp->m_dir_node_ents;
 	/*
 	 * Fill in the path to the entry in the cursor.
 	 */
@@ -1770,6 +1781,7 @@ xfs_dir2_node_removename(
 	state->args = args;
 	state->mp = args->dp->i_mount;
 	state->blocksize = state->mp->m_dirblksize;
+	state->node_ents = state->mp->m_dir_node_ents;
 	/*
 	 * Look up the entry we're deleting, set up the cursor.
 	 */
@@ -1840,6 +1852,7 @@ xfs_dir2_node_replace(
 	state->args = args;
 	state->mp = args->dp->i_mount;
 	state->blocksize = state->mp->m_dirblksize;
+	state->node_ents = state->mp->m_dir_node_ents;
 	inum = args->inumber;
 	/*
 	 * Lookup the entry to change in the btree.
@@ -1918,10 +1931,18 @@ xfs_dir2_node_trim_free(
 	/*
 	 * Read the freespace block.
 	 */
-	if ((error = xfs_da_read_buf(tp, dp, (xfs_dablk_t)fo, -1, &bp,
+	if (unlikely(error = xfs_da_read_buf(tp, dp, (xfs_dablk_t)fo, -2, &bp,
 			XFS_DATA_FORK))) {
 		return error;
 	}
+
+	/*
+	 * There can be holes in freespace.  If fo is a hole, there's
+	 * nothing to do.
+	 */
+	if (bp == NULL) {
+		return 0;
+	}
 	free = bp->data;
 	ASSERT(INT_GET(free->hdr.magic, ARCH_CONVERT) == XFS_DIR2_FREE_MAGIC);
 	/*
