@@ -11,7 +11,7 @@
  *
  * Further, this software is distributed without any warranty that it is
  * free of the rightful claim of any third person regarding infringement
- * or the like.	 Any license provided herein, whether implied or
+ * or the like.  Any license provided herein, whether implied or
  * otherwise, applies only to this software file.  Patent licenses, if
  * any, provided herein do not apply to combinations of this program with
  * other software, or any other product whatsoever.
@@ -114,9 +114,9 @@ xfs_ialloc_ag_alloc(
 	int		*alloc)
 {
 	xfs_agi_t	*agi;		/* allocation group header */
-	xfs_alloc_arg_t args;		/* allocation argument structure */
+	xfs_alloc_arg_t	args;		/* allocation argument structure */
 	int		blks_per_cluster;  /* fs blocks per inode cluster */
-	xfs_btree_cur_t *cur;		/* inode btree cursor */
+	xfs_btree_cur_t	*cur;		/* inode btree cursor */
 	xfs_daddr_t	d;		/* disk addr of buffer */
 	int		error;
 	xfs_buf_t	*fbuf;		/* new free inodes' buffer */
@@ -129,10 +129,9 @@ xfs_ialloc_ag_alloc(
 	int		ninodes;	/* num inodes per buf */
 	xfs_agino_t	thisino;	/* current inode number, for loop */
 	int		version;	/* inode version number to use */
-	static xfs_timestamp_t ztime;	/* zero xfs timestamp */
 	int		isaligned;	/* inode allocation at stripe unit */
 					/* boundary */
-	xfs_dinode_core_t dic;		/* a dinode_core to copy to new */
+	xfs_dinode_core_t dic;          /* a dinode_core to copy to new */
 					/* inodes */
 
 	args.tp = tp;
@@ -205,7 +204,7 @@ xfs_ialloc_ag_alloc(
 		else
 			args.alignment = 1;
 		if ((error = xfs_alloc_vextent(&args)))
-			 return error;
+			return error;
 	}
 
 	if (args.fsbno == NULLFSBLOCK) {
@@ -243,6 +242,11 @@ xfs_ialloc_ag_alloc(
 		version = XFS_DINODE_VERSION_2;
 	else
 		version = XFS_DINODE_VERSION_1;
+
+	memset(&dic, 0, sizeof(xfs_dinode_core_t));
+	INT_SET(dic.di_magic, ARCH_CONVERT, XFS_DINODE_MAGIC);
+	INT_SET(dic.di_version, ARCH_CONVERT, version);
+
 	for (j = 0; j < nbufs; j++) {
 		/*
 		 * Get the block.
@@ -257,36 +261,6 @@ xfs_ialloc_ag_alloc(
 		/*
 		 * Loop over the inodes in this buffer.
 		 */
-		INT_SET(dic.di_magic, ARCH_CONVERT, XFS_DINODE_MAGIC);
-		INT_ZERO(dic.di_mode, ARCH_CONVERT);
-		INT_SET(dic.di_version, ARCH_CONVERT, version);
-		INT_ZERO(dic.di_format, ARCH_CONVERT);
-		INT_ZERO(dic.di_onlink, ARCH_CONVERT);
-		INT_ZERO(dic.di_uid, ARCH_CONVERT);
-		INT_ZERO(dic.di_gid, ARCH_CONVERT);
-		INT_ZERO(dic.di_nlink, ARCH_CONVERT);
-		INT_ZERO(dic.di_projid, ARCH_CONVERT);
-		memset(&(dic.di_pad[0]), 0, sizeof(dic.di_pad));
-		INT_SET(dic.di_atime.t_sec, ARCH_CONVERT, ztime.t_sec);
-		INT_SET(dic.di_atime.t_nsec, ARCH_CONVERT, ztime.t_nsec);
-
-		INT_SET(dic.di_mtime.t_sec, ARCH_CONVERT, ztime.t_sec);
-		INT_SET(dic.di_mtime.t_nsec, ARCH_CONVERT, ztime.t_nsec);
-
-		INT_SET(dic.di_ctime.t_sec, ARCH_CONVERT, ztime.t_sec);
-		INT_SET(dic.di_ctime.t_nsec, ARCH_CONVERT, ztime.t_nsec);
-
-		INT_ZERO(dic.di_size, ARCH_CONVERT);
-		INT_ZERO(dic.di_nblocks, ARCH_CONVERT);
-		INT_ZERO(dic.di_extsize, ARCH_CONVERT);
-		INT_ZERO(dic.di_nextents, ARCH_CONVERT);
-		INT_ZERO(dic.di_anextents, ARCH_CONVERT);
-		INT_ZERO(dic.di_forkoff, ARCH_CONVERT);
-		INT_ZERO(dic.di_aformat, ARCH_CONVERT);
-		INT_ZERO(dic.di_dmevmask, ARCH_CONVERT);
-		INT_ZERO(dic.di_dmstate, ARCH_CONVERT);
-		INT_ZERO(dic.di_flags, ARCH_CONVERT);
-		INT_ZERO(dic.di_gen, ARCH_CONVERT);
 
 		for (i = 0; i < ninodes; i++) {
 			free = XFS_MAKE_IPTR(args.mp, fbuf, i);
@@ -339,9 +313,24 @@ xfs_ialloc_ag_alloc(
 	return 0;
 }
 
+STATIC __inline xfs_agnumber_t
+xfs_ialloc_next_ag(
+	xfs_mount_t	*mp)
+{
+	xfs_agnumber_t	agno;
+
+	spin_lock(&mp->m_agirotor_lock);
+	agno = mp->m_agirotor;
+	if (++mp->m_agirotor == mp->m_maxagi)
+		mp->m_agirotor = 0;
+	spin_unlock(&mp->m_agirotor_lock);
+
+	return agno;
+}
+
 /*
  * Select an allocation group to look for a free inode in, based on the parent
- * inode and then mode.	 Return the allocation group buffer.
+ * inode and then mode.  Return the allocation group buffer.
  */
 STATIC xfs_buf_t *			/* allocation group buffer */
 xfs_ialloc_ag_select(
@@ -369,7 +358,7 @@ xfs_ialloc_ag_select(
 	mp = tp->t_mountp;
 	agcount = mp->m_maxagi;
 	if (S_ISDIR(mode))
-		pagno = atomicIncWithWrap((int *)&mp->m_agirotor, agcount);
+		pagno = xfs_ialloc_next_ag(mp);
 	else {
 		pagno = XFS_INO_TO_AGNO(mp, parent);
 		if (pagno >= agcount)
@@ -397,7 +386,7 @@ xfs_ialloc_ag_select(
 			agbp = NULL;
 
 		if (!pag->pagi_inodeok) {
-			atomicIncWithWrap((int *)&mp->m_agirotor, agcount);
+			xfs_ialloc_next_ag(mp);
 			goto unlock_nextag;
 		}
 
@@ -467,10 +456,10 @@ nextag:
  * The arguments IO_agbp and alloc_done are defined to work within
  * the constraint of one allocation per transaction.
  * xfs_dialloc() is designed to be called twice if it has to do an
- * allocation to make more free inodes.	 On the first call,
+ * allocation to make more free inodes.  On the first call,
  * IO_agbp should be set to NULL. If an inode is available,
  * i.e., xfs_dialloc() did not need to do an allocation, an inode
- * number is returned.	In this case, IO_agbp would be set to the
+ * number is returned.  In this case, IO_agbp would be set to the
  * current ag_buf and alloc_done set to false.
  * If an allocation needed to be done, xfs_dialloc would return
  * the current ag_buf in IO_agbp and set alloc_done to true.
@@ -481,7 +470,7 @@ nextag:
  * guaranteed to have a free inode available.
  *
  * Once we successfully pick an inode its number is returned and the
- * on-disk data structures are updated.	 The inode itself is not read
+ * on-disk data structures are updated.  The inode itself is not read
  * in, since doing so would break ordering constraints with xfs_reclaim.
  */
 int
@@ -499,7 +488,7 @@ xfs_dialloc(
 	xfs_buf_t	*agbp;		/* allocation group header's buffer */
 	xfs_agnumber_t	agno;		/* allocation group number */
 	xfs_agi_t	*agi;		/* allocation group header structure */
-	xfs_btree_cur_t *cur;		/* inode allocation btree cursor */
+	xfs_btree_cur_t	*cur;		/* inode allocation btree cursor */
 	int		error;		/* error return value */
 	int		i;		/* result code */
 	int		ialloced;	/* inode allocation status */
@@ -511,10 +500,10 @@ xfs_dialloc(
 	int		offset;		/* index of inode in chunk */
 	xfs_agino_t	pagino;		/* parent's a.g. relative inode # */
 	xfs_agnumber_t	pagno;		/* parent's allocation group number */
-	xfs_inobt_rec_t rec;		/* inode allocation record */
+	xfs_inobt_rec_t	rec;		/* inode allocation record */
 	xfs_agnumber_t	tagno;		/* testing allocation group number */
-	xfs_btree_cur_t *tcur;		/* temp cursor */
-	xfs_inobt_rec_t trec;		/* temp inode allocation record */
+	xfs_btree_cur_t	*tcur;		/* temp cursor */
+	xfs_inobt_rec_t	trec;		/* temp inode allocation record */
 
 
 	if (*IO_agbp == NULL) {
@@ -926,10 +915,10 @@ xfs_dilocate(
 	__int32_t	chunk_cnt;	/* count of free inodes in chunk */
 	xfs_inofree_t	chunk_free;	/* mask of free inodes in chunk */
 	xfs_agblock_t	cluster_agbno;	/* first block in inode cluster */
-	xfs_btree_cur_t *cur;	/* inode btree cursor */
+	xfs_btree_cur_t	*cur;	/* inode btree cursor */
 	int		error;	/* error code */
 	int		i;	/* temp state */
-	int		offset; /* index of inode in its buffer */
+	int		offset;	/* index of inode in its buffer */
 	int		offset_agbno;	/* blks from chunk start to inode */
 
 	ASSERT(ino != NULLFSINO);
@@ -1099,8 +1088,7 @@ xfs_ialloc_log_agi(
 	xfs_agi_t		*agi;	/* allocation group header */
 
 	agi = XFS_BUF_TO_AGI(bp);
-	ASSERT(INT_GET(agi->agi_magicnum, ARCH_CONVERT) ==
-		XFS_AGI_MAGIC);
+	ASSERT(INT_GET(agi->agi_magicnum, ARCH_CONVERT) == XFS_AGI_MAGIC);
 #endif
 	/*
 	 * Compute byte offsets for the first and last fields.
@@ -1125,34 +1113,31 @@ xfs_ialloc_read_agi(
 	xfs_agi_t	*agi;		/* allocation group header */
 	int		agi_ok;		/* agi is consistent */
 	xfs_buf_t	*bp;		/* allocation group hdr buf */
-    xfs_daddr_t		d;		/* disk block address */
-	int		error;
-#ifdef DEBUG
-	int		i;
-#endif
 	xfs_perag_t	*pag;		/* per allocation group data */
-
+	int		error;
 
 	ASSERT(agno != NULLAGNUMBER);
-	d = XFS_AG_DADDR(mp, agno, XFS_AGI_DADDR);
-	if ((error = xfs_trans_read_buf(mp, tp, mp->m_ddev_targp, d, 1, 0, &bp)))
+	error = xfs_trans_read_buf(
+			mp, tp, mp->m_ddev_targp,
+			XFS_AG_DADDR(mp, agno, XFS_AGI_DADDR(mp)),
+			XFS_FSS_TO_BB(mp, 1), 0, &bp);
+	if (error)
 		return error;
 	ASSERT(bp && !XFS_BUF_GETERROR(bp));
+
 	/*
 	 * Validate the magic number of the agi block.
 	 */
 	agi = XFS_BUF_TO_AGI(bp);
 	agi_ok =
 		INT_GET(agi->agi_magicnum, ARCH_CONVERT) == XFS_AGI_MAGIC &&
-		XFS_AGI_GOOD_VERSION(INT_GET(agi->agi_versionnum, ARCH_CONVERT));
-	if (XFS_TEST_ERROR(!agi_ok, mp, XFS_ERRTAG_IALLOC_READ_AGI,
-			XFS_RANDOM_IALLOC_READ_AGI)) {
+		XFS_AGI_GOOD_VERSION(
+			INT_GET(agi->agi_versionnum, ARCH_CONVERT));
+	if (unlikely(XFS_TEST_ERROR(!agi_ok, mp, XFS_ERRTAG_IALLOC_READ_AGI,
+			XFS_RANDOM_IALLOC_READ_AGI))) {
+		XFS_CORRUPTION_ERROR("xfs_ialloc_read_agi", XFS_ERRLEVEL_LOW,
+				     mp, agi);
 		xfs_trans_brelse(tp, bp);
-#ifdef __KERNEL__	/* additional, temporary, debugging code */
-		cmn_err(CE_NOTE,
-			"EFSCORRUPTED returned from file %s line %d",
-			__FILE__, __LINE__);
-#endif
 		return XFS_ERROR(EFSCORRUPTED);
 	}
 	pag = &mp->m_perag[agno];
@@ -1164,13 +1149,20 @@ xfs_ialloc_read_agi(
 		 * It's possible for these to be out of sync if
 		 * we are in the middle of a forced shutdown.
 		 */
-		ASSERT(pag->pagi_freecount == INT_GET(agi->agi_freecount, ARCH_CONVERT)
+		ASSERT(pag->pagi_freecount ==
+				INT_GET(agi->agi_freecount, ARCH_CONVERT)
 			|| XFS_FORCED_SHUTDOWN(mp));
 	}
+
 #ifdef DEBUG
-	for (i = 0; i < XFS_AGI_UNLINKED_BUCKETS; i++)
-		ASSERT(!INT_ISZERO(agi->agi_unlinked[i], ARCH_CONVERT));
+	{
+		int	i;
+
+		for (i = 0; i < XFS_AGI_UNLINKED_BUCKETS; i++)
+			ASSERT(!INT_ISZERO(agi->agi_unlinked[i], ARCH_CONVERT));
+	}
 #endif
+
 	XFS_BUF_SET_VTYPE_REF(bp, B_FS_AGI, XFS_AGI_REF);
 	*bpp = bp;
 	return 0;
