@@ -30,12 +30,8 @@
  * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
  */
 
-#include <stdio.h>
-#include <fcntl.h>
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-#include <fstyp.h>
+#include <xfs/libxfs.h>
+#include <disk/fstyp.h>
 
 /*
  * fstyp allows the user to determine the filesystem identifier of
