@@ -1,37 +1,36 @@
 /*
- * Copyright (c) 2000-2001 Silicon Graphics, Inc.  All Rights Reserved.
- * 
+ * Copyright (c) 2000-2003 Silicon Graphics, Inc.  All Rights Reserved.
+ *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
+ *
  * This program is distributed in the hope that it would be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
+ *
  * Further, this software is distributed without any warranty that it is
  * free of the rightful claim of any third person regarding infringement
  * or the like.  Any license provided herein, whether implied or
  * otherwise, applies only to this software file.  Patent licenses, if
  * any, provided herein do not apply to combinations of this program with
  * other software, or any other product whatsoever.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write the Free Software Foundation, Inc., 59
  * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
+ *
  * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
  * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
+ *
+ * http://www.sgi.com
+ *
+ * For further information regarding this notice, see:
+ *
  * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
  */
 
 #include <libxfs.h>
-#include <malloc.h>
 #include "agheader.h"
 #include "globals.h"
 #include "protos.h"
@@ -109,12 +108,12 @@ find_secondary_sb(xfs_sb_t *rsb)
 	int		retval;
 	int		bsize;
 
-	do_warn("\nattempting to find secondary superblock...\n");
+	do_warn(_("\nattempting to find secondary superblock...\n"));
 
 	sb = (xfs_sb_t *) memalign(MEM_ALIGN, BSIZE);
 	if (!sb) {
 		do_error(
-	"error finding secondary superblock -- failed to memalign buffer\n");
+	_("error finding secondary superblock -- failed to memalign buffer\n"));
 		exit(1);
 	}
 
@@ -152,23 +151,24 @@ find_secondary_sb(xfs_sb_t *rsb)
 			if (verify_sb(&bufsb, 0) != XR_OK)
 				continue;
 
-			do_warn("found candidate secondary superblock...\n");
+			do_warn(_("found candidate secondary superblock...\n"));
 
 			/*
 			 * found one.  now verify it by looking
 			 * for other secondaries.
 			 */
-			bcopy(&bufsb, rsb, bufsb.sb_sectsize);
+			bcopy(&bufsb, rsb, sizeof(xfs_sb_t));
 			rsb->sb_inprogress = 0;
 			clear_sunit = 1;
 
 			if (verify_set_primary_sb(rsb, 0, &dirty) == XR_OK)  {
-				do_warn("verified secondary superblock...\n");
+				do_warn(
+			_("verified secondary superblock...\n"));
 				done = 1;
 				retval = 1;
 			} else  {
 				do_warn(
-				"unable to verify superblock, continuing...\n");
+			_("unable to verify superblock, continuing...\n"));
 			}
 		}
 	}
@@ -219,6 +219,8 @@ calc_ino_align(xfs_sb_t *sb)
  * sector size info -
  *			sb_sectsize
  *			sb_sectlog
+ *			sb_logsectsize
+ *			sb_logsectlog
  *
  * not checked here -
  *			sb_rootino
@@ -237,7 +239,7 @@ verify_sb(xfs_sb_t *sb, int is_primary_sb)
 	__uint32_t	bsize;
 	xfs_extlen_t	align;
 	int		i;
-	
+
 	/* check magic number and version number */
 
 	if (sb->sb_magicnum != XFS_SB_MAGIC)
@@ -258,11 +260,11 @@ verify_sb(xfs_sb_t *sb, int is_primary_sb)
 
 	bsize = 1;
 
-	for (i = 0; bsize < sb->sb_blocksize && i < 32; i++)  {
+	for (i = 0; bsize < sb->sb_blocksize &&
+		i < sizeof(sb->sb_blocksize) * NBBY; i++)
 		bsize <<= 1;
-	}
 
-	if (i < XR_LOG2BSIZE_MIN || i > XR_LOG2BSIZE_MAX)
+	if (i < XFS_MIN_BLOCKSIZE_LOG || i > XFS_MAX_BLOCKSIZE_LOG)
 		return(XR_BAD_BLOCKSIZE);
 
 	/* check sb blocksize field against sb blocklog field */
@@ -273,9 +275,11 @@ verify_sb(xfs_sb_t *sb, int is_primary_sb)
 	/* sanity check ag count, size fields against data size field */
 
 	if (sb->sb_dblocks == 0 ||
-		sb->sb_dblocks > sb->sb_agcount * sb->sb_agblocks ||
-		sb->sb_dblocks < (sb->sb_agcount - 1)
-			* sb->sb_agblocks + XFS_MIN_AG_BLOCKS)
+		sb->sb_dblocks >
+			((__uint64_t)sb->sb_agcount * sb->sb_agblocks) ||
+		sb->sb_dblocks <
+			((__uint64_t)(sb->sb_agcount - 1) * sb->sb_agblocks
+			+ XFS_MIN_AG_BLOCKS))
 		return(XR_BAD_FS_SIZE_DATA);
 
 	if (sb->sb_agblklog != (__uint8_t)libxfs_log2_roundup(sb->sb_agblocks))
@@ -286,18 +290,49 @@ verify_sb(xfs_sb_t *sb, int is_primary_sb)
 		sb->sb_inopblock != howmany(sb->sb_blocksize,sb->sb_inodesize))
 		return(XR_BAD_INO_SIZE_DATA);
 
-	/* check sector size against log(sector size) field */
+	/* check to make sure sectorsize is legal 2^N, 9 <= N <= 15 */
+
+	if (sb->sb_sectsize == 0)
+		return(XR_BAD_SECT_SIZE_DATA);
 
 	bsize = 1;
 
-	for (i = 0; bsize < sb->sb_sectsize && i < 15; i++)  {
+	for (i = 0; bsize < sb->sb_sectsize &&
+		i < sizeof(sb->sb_sectsize) * NBBY; i++)  {
 		bsize <<= 1;
 	}
 
-	if (sb->sb_sectsize == 0 || i == 16 ||
-			sb->sb_sectsize != (1 << i))
+	if (i < XFS_MIN_SECTORSIZE_LOG || i > XFS_MAX_SECTORSIZE_LOG)
 		return(XR_BAD_SECT_SIZE_DATA);
 
+	/* check sb sectorsize field against sb sectlog field */
+
+	if (i != sb->sb_sectlog)
+		return(XR_BAD_SECT_SIZE_DATA);
+
+	if (XFS_SB_VERSION_HASSECTOR(sb))  {
+
+		/* check to make sure log sector is legal 2^N, 9 <= N <= 15 */
+
+		if (sb->sb_logsectsize == 0)
+			return(XR_BAD_SECT_SIZE_DATA);
+
+		bsize = 1;
+
+		for (i = 0; bsize < sb->sb_logsectsize &&
+			i < sizeof(sb->sb_logsectsize) * NBBY; i++)  {
+			bsize <<= 1;
+		}
+
+		if (i < XFS_MIN_SECTORSIZE_LOG || i > XFS_MAX_SECTORSIZE_LOG)
+			return(XR_BAD_SECT_SIZE_DATA);
+
+		/* check sb log sectorsize field against sb log sectlog field */
+
+		if (i != sb->sb_logsectlog)
+			return(XR_BAD_SECT_SIZE_DATA);
+	}
+
 	/*
 	 * real-time extent size is always set
 	 */
@@ -355,8 +390,8 @@ verify_sb(xfs_sb_t *sb, int is_primary_sb)
 	 * verify stripe alignment fields if present
 	 */
 	if (XFS_SB_VERSION_HASDALIGN(sb)) {
-		if ((!sb->sb_unit && sb->sb_width) || 
-		    (sb->sb_unit && sb->sb_agblocks % sb->sb_unit)) 
+		if ((!sb->sb_unit && sb->sb_width) ||
+		    (sb->sb_unit && sb->sb_agblocks % sb->sb_unit))
 			return(XR_BAD_SB_UNIT);
 		if ((sb->sb_unit && !sb->sb_width) ||
 		    (sb->sb_width && sb->sb_unit && sb->sb_width % sb->sb_unit))
@@ -424,29 +459,29 @@ verify_sb(xfs_sb_t *sb, int is_primary_sb)
 void
 write_primary_sb(xfs_sb_t *sbp, int size)
 {
-        void *buf;
-        
+	void *buf;
+
 	if (no_modify)
 		return;
-        
-        if ((buf = calloc(size, 1)) == NULL) {
-		do_error("failed to malloc superblock buffer\n");
-                return;
+
+	if ((buf = calloc(size, 1)) == NULL) {
+		do_error(_("failed to malloc superblock buffer\n"));
+		return;
 	}
 
 	if (lseek64(fs_fd, 0LL, SEEK_SET) != 0LL) {
-                free(buf);
-		do_error("couldn't seek to offset 0 in filesystem\n");
-        }
-        
+		free(buf);
+		do_error(_("couldn't seek to offset 0 in filesystem\n"));
+	}
+
 	libxfs_xlate_sb(buf, sbp, -1, ARCH_CONVERT, XFS_SB_ALL_BITS);
 
 	if (write(fs_fd, buf, size) != size) {
-                free(buf);
-		do_error("primary superblock write failed!\n");
-        }
+		free(buf);
+		do_error(_("primary superblock write failed!\n"));
+	}
 
-        free(buf);
+	free(buf);
 }
 
 /*
@@ -456,11 +491,11 @@ int
 get_sb(xfs_sb_t *sbp, xfs_off_t off, int size, xfs_agnumber_t agno)
 {
 	int error, rval;
-        void *buf;
-        
-        if ((buf = calloc(size, 1)) == NULL) {
+	void *buf;
+
+	if ((buf = calloc(size, 1)) == NULL) {
 		do_error(
-	"error reading superblock %u -- failed to malloc buffer\n",
+	_("error reading superblock %u -- failed to malloc buffer\n"),
 			agno, off);
 		exit(1);
 	}
@@ -469,7 +504,7 @@ get_sb(xfs_sb_t *sbp, xfs_off_t off, int size, xfs_agnumber_t agno)
 
 	if (lseek64(fs_fd, off, SEEK_SET) != off)  {
 		do_warn(
-	"error reading superblock %u -- seek to offset %lld failed\n",
+	_("error reading superblock %u -- seek to offset %lld failed\n"),
 			agno, off);
 		return(XR_EOF);
 	}
@@ -477,7 +512,7 @@ get_sb(xfs_sb_t *sbp, xfs_off_t off, int size, xfs_agnumber_t agno)
 	if ((rval = read(fs_fd, buf, size)) != size)  {
 		error = errno;
 		do_warn(
-"superblock read failed, offset %lld, size %d, ag %u, rval %d\n",
+	_("superblock read failed, offset %lld, size %d, ag %u, rval %d\n"),
 			off, size, rval, agno);
 		do_error("%s\n", strerror(error));
 	}
@@ -539,7 +574,7 @@ fs_geo_list_t *
 add_geo(fs_geo_list_t *list, fs_geometry_t *geo_p, int index)
 {
 	fs_geo_list_t	*current = list;
-	
+
 	while (current != NULL)  {
 		if (memcmp(geo_p, &current->geo, sizeof(fs_geometry_t)) == 0)  {
 			current->refs++;
@@ -550,7 +585,7 @@ add_geo(fs_geo_list_t *list, fs_geometry_t *geo_p, int index)
 	}
 
 	if ((current = malloc(sizeof(fs_geo_list_t))) == NULL) {
-		do_error("couldn't malloc geometry structure\n");
+		do_error(_("couldn't malloc geometry structure\n"));
 		exit(1);
 	}
 
@@ -667,7 +702,7 @@ verify_set_primary_sb(xfs_sb_t		*rsb,
 			int		sb_index,
 			int		*sb_modified)
 {
-	xfs_off_t		off;
+	xfs_off_t	off;
 	fs_geometry_t	geo;
 	xfs_sb_t	*sb;
 	fs_geo_list_t	*list;
@@ -695,7 +730,7 @@ verify_set_primary_sb(xfs_sb_t		*rsb,
 	sb = (xfs_sb_t *) alloc_ag_buf(size);
 	checked = calloc(rsb->sb_agcount, sizeof(char));
 	if (!checked) {
-		do_error("calloc failed in verify_set_primary_sb\n");
+		do_error(_("calloc failed in verify_set_primary_sb\n"));
 		exit(1);
 	}
 
@@ -762,7 +797,8 @@ verify_set_primary_sb(xfs_sb_t		*rsb,
 		 */
 		if (current->refs != 2)  {
 			if (!force_geo)  {
-				do_warn("Only two AGs detected and they do not match - cannot proceed.\n");
+				do_warn(
+	_("Only two AGs detected and they do not match - cannot proceed.\n"));
 				exit(1);
 			}
 		}
@@ -774,7 +810,7 @@ verify_set_primary_sb(xfs_sb_t		*rsb,
 		 * option is in effect.
 		 */
 		if (!force_geo)  {
-			do_warn("Only one AG detected - cannot proceed.\n");
+			do_warn(_("Only one AG detected - cannot proceed.\n"));
 			exit(1);
 		}
 	default:
@@ -785,7 +821,8 @@ verify_set_primary_sb(xfs_sb_t		*rsb,
 		 * XFS normally doesn't alter the secondary superblocks.
 		 */
 		if (current->refs < num_sbs / 2)  {
-			do_warn("Not enough matching superblocks - cannot proceed.\n");
+			do_warn(
+		_("Not enough matching superblocks - cannot proceed.\n"));
 			exit(1);
 		}
 	}
@@ -796,11 +833,11 @@ verify_set_primary_sb(xfs_sb_t		*rsb,
 
 	if (current->index != sb_index)  {
 		*sb_modified = 1;
-		off = current->index * current->geo.sb_agblocks 
+		off = current->index * current->geo.sb_agblocks
 			* current->geo.sb_blocksize;
 		if (get_sb(sb, off, current->geo.sb_sectsize,
 				current->index) != XR_OK)
-			do_error("could not read superblock\n");
+			do_error(_("could not read superblock\n"));
 
 		copy_sb(sb, rsb);
 
